# -*- coding:utf-8 -*-

query = u'https://en.wikipedia.org/w/api.php?action=query&bllimit=500&bltitle=Douglas%20Adams&cllimit=500&clshow=!hidden&formatversion=2&imlimit=500&list=backlinks&lllimit=500&pclimit=500&prop=categories|contributors|images|langlinks|pageviews&redirects&titles=Douglas%20Adams'

response = r"""
{
    "continue": {
        "blcontinue": "4|2028922",
        "pccontinue": "8091|808533",
        "continue": "||categories|images|langlinks|pageviews"
    },
    "query": {
        "pages": [
            {
                "pageid": 8091,
                "ns": 0,
                "title": "Douglas Adams",
                "categories": [
                    {
                        "ns": 14,
                        "title": "Category:1952 births"
                    },
                    {
                        "ns": 14,
                        "title": "Category:2001 deaths"
                    },
                    {
                        "ns": 14,
                        "title": "Category:20th-century English novelists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:20th-century atheists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:21st-century British novelists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:21st-century atheists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Alumni of St John's College, Cambridge"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Audiobook narrators"
                    },
                    {
                        "ns": 14,
                        "title": "Category:BBC radio producers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:British atheism activists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:British child writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Burials at Highgate Cemetery"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Critics of religions"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Douglas Adams"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English atheists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English comedy writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English humanists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English humorists"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English radio writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English science fiction writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English social commentators"
                    },
                    {
                        "ns": 14,
                        "title": "Category:English television writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Infocom"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Interactive fiction writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Monty Python"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Non-fiction environmental writers"
                    },
                    {
                        "ns": 14,
                        "title": "Category:People educated at Brentwood School (Essex)"
                    },
                    {
                        "ns": 14,
                        "title": "Category:People from Cambridge"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Simon & Schuster authors"
                    },
                    {
                        "ns": 14,
                        "title": "Category:Usenet people"
                    }
                ],
                "anoncontributors": 829,
                "contributors": [
                    {
                        "userid": 16,
                        "name": "General Wesc"
                    },
                    {
                        "userid": 52,
                        "name": "Eloquence"
                    },
                    {
                        "userid": 74,
                        "name": "Espen"
                    },
                    {
                        "userid": 83,
                        "name": "Tarquin"
                    },
                    {
                        "userid": 90,
                        "name": "Koyaanis Qatsi"
                    },
                    {
                        "userid": 584,
                        "name": "Danny"
                    },
                    {
                        "userid": 637,
                        "name": "Shsilver"
                    },
                    {
                        "userid": 672,
                        "name": "XJaM"
                    },
                    {
                        "userid": 835,
                        "name": "Rmhermen"
                    },
                    {
                        "userid": 1411,
                        "name": "Roadrunner"
                    },
                    {
                        "userid": 1591,
                        "name": "SimonP"
                    },
                    {
                        "userid": 1743,
                        "name": "Ben-Zin~enwiki"
                    },
                    {
                        "userid": 2214,
                        "name": "Ellmist"
                    },
                    {
                        "userid": 3278,
                        "name": "Fonzy"
                    },
                    {
                        "userid": 3295,
                        "name": "Mintguy"
                    },
                    {
                        "userid": 3350,
                        "name": "Sue"
                    },
                    {
                        "userid": 3624,
                        "name": "Tzartzam"
                    },
                    {
                        "userid": 4145,
                        "name": "Rbrwr"
                    },
                    {
                        "userid": 4259,
                        "name": "Frecklefoot"
                    },
                    {
                        "userid": 4261,
                        "name": "Edward"
                    },
                    {
                        "userid": 4623,
                        "name": "Tillwe"
                    },
                    {
                        "userid": 5333,
                        "name": "Oliver Pereira"
                    },
                    {
                        "userid": 5687,
                        "name": "Wm"
                    },
                    {
                        "userid": 5861,
                        "name": "Liftarn"
                    },
                    {
                        "userid": 5894,
                        "name": "Gabbe"
                    },
                    {
                        "userid": 6120,
                        "name": "Rambot"
                    },
                    {
                        "userid": 6458,
                        "name": "Tango"
                    },
                    {
                        "userid": 6511,
                        "name": "Cyde"
                    },
                    {
                        "userid": 6661,
                        "name": "Paul Benjamin Austin"
                    },
                    {
                        "userid": 6827,
                        "name": "Delirium"
                    },
                    {
                        "userid": 6995,
                        "name": "Skysmith"
                    },
                    {
                        "userid": 7104,
                        "name": "Paul A"
                    },
                    {
                        "userid": 7140,
                        "name": "Atticus~enwiki"
                    },
                    {
                        "userid": 7402,
                        "name": "Tregoweth"
                    },
                    {
                        "userid": 7540,
                        "name": "Ellywa"
                    },
                    {
                        "userid": 7912,
                        "name": "Talh~enwiki"
                    },
                    {
                        "userid": 8351,
                        "name": "TUF-KAT"
                    },
                    {
                        "userid": 8551,
                        "name": "Angela"
                    },
                    {
                        "userid": 8683,
                        "name": "Anorak~enwiki"
                    },
                    {
                        "userid": 8776,
                        "name": "Jdforrester"
                    },
                    {
                        "userid": 8817,
                        "name": "Rlandmann"
                    },
                    {
                        "userid": 8875,
                        "name": "Poetscientistdrinker"
                    },
                    {
                        "userid": 8926,
                        "name": "Александър"
                    },
                    {
                        "userid": 9102,
                        "name": "Salsa Shark"
                    },
                    {
                        "userid": 9177,
                        "name": "Jll"
                    },
                    {
                        "userid": 9439,
                        "name": "Ffx"
                    },
                    {
                        "userid": 9475,
                        "name": "Bogdangiusca"
                    },
                    {
                        "userid": 9759,
                        "name": "Nikai"
                    },
                    {
                        "userid": 9864,
                        "name": "Susurrus"
                    },
                    {
                        "userid": 9932,
                        "name": "Big iron"
                    },
                    {
                        "userid": 9993,
                        "name": "Cimon Avaro"
                    },
                    {
                        "userid": 10080,
                        "name": "Cema"
                    },
                    {
                        "userid": 10096,
                        "name": "Palfrey"
                    },
                    {
                        "userid": 10719,
                        "name": "Harry Potter"
                    },
                    {
                        "userid": 12978,
                        "name": "Charles Matthews"
                    },
                    {
                        "userid": 13277,
                        "name": "Jihg"
                    },
                    {
                        "userid": 13476,
                        "name": "Dcoetzee"
                    },
                    {
                        "userid": 15135,
                        "name": "Slark"
                    },
                    {
                        "userid": 15756,
                        "name": "Wik"
                    },
                    {
                        "userid": 15789,
                        "name": "Zoicon5"
                    },
                    {
                        "userid": 15865,
                        "name": "Steinsky"
                    },
                    {
                        "userid": 16276,
                        "name": "Markhurd"
                    },
                    {
                        "userid": 16692,
                        "name": "Kgajos"
                    },
                    {
                        "userid": 16710,
                        "name": "Tpbradbury"
                    },
                    {
                        "userid": 16924,
                        "name": "Maximus Rex"
                    },
                    {
                        "userid": 17163,
                        "name": "Furrykef"
                    },
                    {
                        "userid": 17226,
                        "name": "Grendelkhan"
                    },
                    {
                        "userid": 17287,
                        "name": "Morwen"
                    },
                    {
                        "userid": 17456,
                        "name": "Itai"
                    },
                    {
                        "userid": 17790,
                        "name": "Nv8200pa"
                    },
                    {
                        "userid": 18084,
                        "name": "Tempshill"
                    },
                    {
                        "userid": 18454,
                        "name": "Gutsul"
                    },
                    {
                        "userid": 19619,
                        "name": "Bevo"
                    },
                    {
                        "userid": 19827,
                        "name": "Spikey"
                    },
                    {
                        "userid": 20178,
                        "name": "Lord Emsworth"
                    },
                    {
                        "userid": 21036,
                        "name": "Dpbsmith"
                    },
                    {
                        "userid": 23320,
                        "name": "Owen"
                    },
                    {
                        "userid": 24198,
                        "name": "Dimadick"
                    },
                    {
                        "userid": 24373,
                        "name": "Phil Boswell"
                    },
                    {
                        "userid": 24744,
                        "name": "Donarreiskoffer"
                    },
                    {
                        "userid": 25261,
                        "name": "Robbot"
                    },
                    {
                        "userid": 25630,
                        "name": "Popageorgio"
                    },
                    {
                        "userid": 25935,
                        "name": "Xuanwu"
                    },
                    {
                        "userid": 26068,
                        "name": "Sander123"
                    },
                    {
                        "userid": 26248,
                        "name": "Pigsonthewing"
                    },
                    {
                        "userid": 26939,
                        "name": "Korath"
                    },
                    {
                        "userid": 27266,
                        "name": "Matt me"
                    },
                    {
                        "userid": 27822,
                        "name": "RedWolf"
                    },
                    {
                        "userid": 29695,
                        "name": "Postdlf"
                    },
                    {
                        "userid": 29986,
                        "name": "Merovingian"
                    },
                    {
                        "userid": 31280,
                        "name": "Texture"
                    },
                    {
                        "userid": 31383,
                        "name": "Litefantastic"
                    },
                    {
                        "userid": 31706,
                        "name": "Auric"
                    },
                    {
                        "userid": 31951,
                        "name": "LGagnon"
                    },
                    {
                        "userid": 32005,
                        "name": "Timrollpickering"
                    },
                    {
                        "userid": 33417,
                        "name": "Wikibot"
                    },
                    {
                        "userid": 33452,
                        "name": "Ddstretch"
                    },
                    {
                        "userid": 33566,
                        "name": "JackofOz"
                    },
                    {
                        "userid": 34433,
                        "name": "Dhodges"
                    },
                    {
                        "userid": 34459,
                        "name": "MykReeve"
                    },
                    {
                        "userid": 35184,
                        "name": "HaeB"
                    },
                    {
                        "userid": 35742,
                        "name": "Jleedev"
                    },
                    {
                        "userid": 36424,
                        "name": "Enochlau"
                    },
                    {
                        "userid": 38020,
                        "name": "Dbenbenn"
                    },
                    {
                        "userid": 39883,
                        "name": "Andrew Bailey"
                    },
                    {
                        "userid": 40231,
                        "name": "Barbara Shack"
                    },
                    {
                        "userid": 41710,
                        "name": "Inkling"
                    },
                    {
                        "userid": 41799,
                        "name": "BenFrantzDale"
                    },
                    {
                        "userid": 41983,
                        "name": "Ævar Arnfjörð Bjarmason"
                    },
                    {
                        "userid": 41995,
                        "name": "Netoholic"
                    },
                    {
                        "userid": 42062,
                        "name": "Lethe"
                    },
                    {
                        "userid": 42254,
                        "name": "Meursault2004"
                    },
                    {
                        "userid": 42385,
                        "name": "Lupin"
                    },
                    {
                        "userid": 42424,
                        "name": "Brian Kendig"
                    },
                    {
                        "userid": 42847,
                        "name": "Angmering"
                    },
                    {
                        "userid": 42935,
                        "name": "Dissident"
                    },
                    {
                        "userid": 43108,
                        "name": "Bfinn"
                    },
                    {
                        "userid": 43152,
                        "name": "Ausir"
                    },
                    {
                        "userid": 43530,
                        "name": "Bradeos Graphon"
                    },
                    {
                        "userid": 43642,
                        "name": "Muke"
                    },
                    {
                        "userid": 43680,
                        "name": "Peruvianllama"
                    },
                    {
                        "userid": 44062,
                        "name": "Bkonrad"
                    },
                    {
                        "userid": 44400,
                        "name": "Mpntod"
                    },
                    {
                        "userid": 44727,
                        "name": "Curps"
                    },
                    {
                        "userid": 45336,
                        "name": "Wikibob"
                    },
                    {
                        "userid": 45645,
                        "name": "Varlaam"
                    },
                    {
                        "userid": 45998,
                        "name": "Ssd"
                    },
                    {
                        "userid": 46083,
                        "name": "Cantus"
                    },
                    {
                        "userid": 47912,
                        "name": "Scott Wilson"
                    },
                    {
                        "userid": 47960,
                        "name": "Guanaco"
                    },
                    {
                        "userid": 49200,
                        "name": "Robbrown"
                    },
                    {
                        "userid": 50095,
                        "name": "Brockert"
                    },
                    {
                        "userid": 50930,
                        "name": "Just Another Dan"
                    },
                    {
                        "userid": 51235,
                        "name": "Bobblewik"
                    },
                    {
                        "userid": 51984,
                        "name": "Bullfrogger"
                    },
                    {
                        "userid": 53060,
                        "name": "TerokNor"
                    },
                    {
                        "userid": 53222,
                        "name": "Neilc"
                    },
                    {
                        "userid": 54381,
                        "name": "Gadfium"
                    },
                    {
                        "userid": 54890,
                        "name": "SoWhy"
                    },
                    {
                        "userid": 55014,
                        "name": "Andycjp"
                    },
                    {
                        "userid": 55239,
                        "name": "Dunk"
                    },
                    {
                        "userid": 55547,
                        "name": "Toytoy"
                    },
                    {
                        "userid": 56905,
                        "name": "LucasVB"
                    },
                    {
                        "userid": 57108,
                        "name": "Quadell"
                    },
                    {
                        "userid": 57658,
                        "name": "Antandrus"
                    },
                    {
                        "userid": 58666,
                        "name": "MarkSweep"
                    },
                    {
                        "userid": 59002,
                        "name": "Piotrus"
                    },
                    {
                        "userid": 60133,
                        "name": "Khaosworks"
                    },
                    {
                        "userid": 60418,
                        "name": "Andux"
                    },
                    {
                        "userid": 61329,
                        "name": "Rdsmith4"
                    },
                    {
                        "userid": 62058,
                        "name": "DragonflySixtyseven"
                    },
                    {
                        "userid": 63066,
                        "name": "RetiredUser2"
                    },
                    {
                        "userid": 63762,
                        "name": "Bodnotbod"
                    },
                    {
                        "userid": 64439,
                        "name": "Kuralyov"
                    },
                    {
                        "userid": 64669,
                        "name": "Pmanderson"
                    },
                    {
                        "userid": 64791,
                        "name": "Elroch"
                    },
                    {
                        "userid": 67647,
                        "name": "TonyW"
                    },
                    {
                        "userid": 68496,
                        "name": "Pitchka"
                    },
                    {
                        "userid": 70592,
                        "name": "JohnArmagh"
                    },
                    {
                        "userid": 72695,
                        "name": "Kadambarid"
                    },
                    {
                        "userid": 73333,
                        "name": "Trevor MacInnis"
                    },
                    {
                        "userid": 73608,
                        "name": "Guybrush"
                    },
                    {
                        "userid": 74053,
                        "name": "Gcanyon"
                    },
                    {
                        "userid": 74123,
                        "name": "EagleOne"
                    },
                    {
                        "userid": 74199,
                        "name": "Esperant"
                    },
                    {
                        "userid": 74425,
                        "name": "RevRagnarok"
                    },
                    {
                        "userid": 74943,
                        "name": "Grstain"
                    },
                    {
                        "userid": 75174,
                        "name": "Ayager"
                    },
                    {
                        "userid": 75230,
                        "name": "Mike Rosoft"
                    },
                    {
                        "userid": 75561,
                        "name": "D6"
                    },
                    {
                        "userid": 78345,
                        "name": "AliveFreeHappy"
                    },
                    {
                        "userid": 79210,
                        "name": "Bonalaw"
                    },
                    {
                        "userid": 80769,
                        "name": "Sysy"
                    },
                    {
                        "userid": 80866,
                        "name": "CALR"
                    },
                    {
                        "userid": 80949,
                        "name": "Slady"
                    },
                    {
                        "userid": 81106,
                        "name": "Bruzie"
                    },
                    {
                        "userid": 82697,
                        "name": "Bri"
                    },
                    {
                        "userid": 82835,
                        "name": "Rich Farmbrough"
                    },
                    {
                        "userid": 82899,
                        "name": "Rhobite"
                    },
                    {
                        "userid": 83172,
                        "name": "Mrevan"
                    },
                    {
                        "userid": 83978,
                        "name": "Qutezuce"
                    },
                    {
                        "userid": 84495,
                        "name": "Jpk"
                    },
                    {
                        "userid": 84942,
                        "name": "Silence"
                    },
                    {
                        "userid": 85186,
                        "name": "Dave souza"
                    },
                    {
                        "userid": 86855,
                        "name": "Arthur Holland"
                    },
                    {
                        "userid": 87355,
                        "name": "Paul August"
                    },
                    {
                        "userid": 88026,
                        "name": "Bender235"
                    },
                    {
                        "userid": 89559,
                        "name": "Elykyllek"
                    },
                    {
                        "userid": 90010,
                        "name": "Wyldeone"
                    },
                    {
                        "userid": 90356,
                        "name": "Billlion"
                    },
                    {
                        "userid": 93172,
                        "name": "Gitaroo Man"
                    },
                    {
                        "userid": 94120,
                        "name": "PhilHibbs"
                    },
                    {
                        "userid": 94806,
                        "name": "RoyBoy"
                    },
                    {
                        "userid": 94900,
                        "name": "EurekaLott"
                    },
                    {
                        "userid": 95049,
                        "name": "Darthnice"
                    },
                    {
                        "userid": 98848,
                        "name": "Renamed User dSgaUUTyFy"
                    },
                    {
                        "userid": 99587,
                        "name": "Nick Smale"
                    },
                    {
                        "userid": 100426,
                        "name": "Smalljim"
                    },
                    {
                        "userid": 100950,
                        "name": "Davidswelt"
                    },
                    {
                        "userid": 100952,
                        "name": "Revolutionary"
                    },
                    {
                        "userid": 103429,
                        "name": "Librarygurl"
                    },
                    {
                        "userid": 104381,
                        "name": "JW1805"
                    },
                    {
                        "userid": 105150,
                        "name": "DaveGorman"
                    },
                    {
                        "userid": 109479,
                        "name": "Rje"
                    },
                    {
                        "userid": 111640,
                        "name": "(aeropagitica)"
                    },
                    {
                        "userid": 112503,
                        "name": "Sunny day~enwiki"
                    },
                    {
                        "userid": 113744,
                        "name": "Supersexyspacemonkey"
                    },
                    {
                        "userid": 114802,
                        "name": "Jez"
                    },
                    {
                        "userid": 116143,
                        "name": "Ranveig"
                    },
                    {
                        "userid": 116385,
                        "name": "Jumbuck"
                    },
                    {
                        "userid": 116587,
                        "name": "Schissel"
                    },
                    {
                        "userid": 116612,
                        "name": "Rsholmes"
                    },
                    {
                        "userid": 118298,
                        "name": "Thejabberwock"
                    },
                    {
                        "userid": 118722,
                        "name": "Alansohn"
                    },
                    {
                        "userid": 120043,
                        "name": "Uncle Bill"
                    },
                    {
                        "userid": 123849,
                        "name": "Querent"
                    },
                    {
                        "userid": 124152,
                        "name": "Philip Cross"
                    },
                    {
                        "userid": 124371,
                        "name": "Keenan Pepper"
                    },
                    {
                        "userid": 124674,
                        "name": "Carbon Caryatid"
                    },
                    {
                        "userid": 124782,
                        "name": "PatrickFisher"
                    },
                    {
                        "userid": 125125,
                        "name": "Penwhale"
                    },
                    {
                        "userid": 125436,
                        "name": "Hipocrite"
                    },
                    {
                        "userid": 127427,
                        "name": "Mmmready"
                    },
                    {
                        "userid": 128005,
                        "name": "Ashley Pomeroy"
                    },
                    {
                        "userid": 128863,
                        "name": "Lectonar"
                    },
                    {
                        "userid": 129409,
                        "name": "SlimVirgin"
                    },
                    {
                        "userid": 129517,
                        "name": "Fwb44"
                    },
                    {
                        "userid": 130135,
                        "name": "Lightdarkness"
                    },
                    {
                        "userid": 130237,
                        "name": "Ciaran H"
                    },
                    {
                        "userid": 132185,
                        "name": "InShaneee"
                    },
                    {
                        "userid": 132864,
                        "name": "Rohirok"
                    },
                    {
                        "userid": 133241,
                        "name": "Mysdaao"
                    },
                    {
                        "userid": 137159,
                        "name": "Bbsrock"
                    },
                    {
                        "userid": 137678,
                        "name": "SidP"
                    },
                    {
                        "userid": 138511,
                        "name": "Saga City"
                    },
                    {
                        "userid": 138667,
                        "name": "Fourthords"
                    },
                    {
                        "userid": 139037,
                        "name": "Peter B."
                    },
                    {
                        "userid": 139248,
                        "name": "Uucp"
                    },
                    {
                        "userid": 140084,
                        "name": "Cburnett"
                    },
                    {
                        "userid": 141662,
                        "name": "Tony Sidaway"
                    },
                    {
                        "userid": 143018,
                        "name": "Xayma"
                    },
                    {
                        "userid": 144440,
                        "name": "Imdwalrus"
                    },
                    {
                        "userid": 144968,
                        "name": "Nicknack009"
                    },
                    {
                        "userid": 145194,
                        "name": "H2g2bob"
                    },
                    {
                        "userid": 145197,
                        "name": "P Ingerson"
                    },
                    {
                        "userid": 145615,
                        "name": "Brendanl79"
                    },
                    {
                        "userid": 145925,
                        "name": "Kyven"
                    },
                    {
                        "userid": 147699,
                        "name": "Eric Herboso"
                    },
                    {
                        "userid": 152145,
                        "name": "Red dwarf"
                    },
                    {
                        "userid": 152918,
                        "name": "Kenyon"
                    },
                    {
                        "userid": 152983,
                        "name": "Dismas"
                    },
                    {
                        "userid": 153805,
                        "name": "Ashujo"
                    },
                    {
                        "userid": 155383,
                        "name": "Pcpcpc"
                    },
                    {
                        "userid": 155447,
                        "name": "Dejvid"
                    },
                    {
                        "userid": 155918,
                        "name": "Tristessa de St Ange"
                    },
                    {
                        "userid": 158241,
                        "name": "Kelly Martin"
                    },
                    {
                        "userid": 160254,
                        "name": "Dalmoz~enwiki"
                    },
                    {
                        "userid": 160510,
                        "name": "Raven42"
                    },
                    {
                        "userid": 160806,
                        "name": "FeanorStar7"
                    },
                    {
                        "userid": 161478,
                        "name": "TigerShark"
                    },
                    {
                        "userid": 161557,
                        "name": "Scriberius"
                    },
                    {
                        "userid": 162348,
                        "name": "PaulHammond"
                    },
                    {
                        "userid": 162655,
                        "name": "Nuggetboy"
                    },
                    {
                        "userid": 165613,
                        "name": "Carcharoth"
                    },
                    {
                        "userid": 166073,
                        "name": "BillC"
                    },
                    {
                        "userid": 167399,
                        "name": "Bratsche"
                    },
                    {
                        "userid": 167610,
                        "name": "MattGiuca"
                    },
                    {
                        "userid": 169503,
                        "name": "Thepctick"
                    },
                    {
                        "userid": 170135,
                        "name": "Dodiad"
                    },
                    {
                        "userid": 170381,
                        "name": "JeremyA"
                    },
                    {
                        "userid": 171533,
                        "name": "Exxolon"
                    },
                    {
                        "userid": 172527,
                        "name": "The Jake"
                    },
                    {
                        "userid": 176569,
                        "name": "Thruston"
                    },
                    {
                        "userid": 177353,
                        "name": "Damicatz"
                    },
                    {
                        "userid": 179697,
                        "name": "GregorB"
                    },
                    {
                        "userid": 180201,
                        "name": "Isnow"
                    },
                    {
                        "userid": 182379,
                        "name": "CharlesC"
                    },
                    {
                        "userid": 184087,
                        "name": "Wayward"
                    },
                    {
                        "userid": 185663,
                        "name": "ZephyrAnycon"
                    },
                    {
                        "userid": 186336,
                        "name": "DavidFarmbrough"
                    },
                    {
                        "userid": 186783,
                        "name": "Wayfarer1706"
                    },
                    {
                        "userid": 194203,
                        "name": "Graham87"
                    },
                    {
                        "userid": 196662,
                        "name": "NoPuzzleStranger"
                    },
                    {
                        "userid": 196944,
                        "name": "Wachholder0"
                    },
                    {
                        "userid": 197953,
                        "name": "Kbdank71"
                    },
                    {
                        "userid": 198939,
                        "name": "JIP"
                    },
                    {
                        "userid": 200152,
                        "name": "Dpr"
                    },
                    {
                        "userid": 203434,
                        "name": "Rjwilmsi"
                    },
                    {
                        "userid": 203494,
                        "name": "Mayumashu"
                    },
                    {
                        "userid": 203786,
                        "name": "Tim!"
                    },
                    {
                        "userid": 204692,
                        "name": "Nightscream"
                    },
                    {
                        "userid": 205121,
                        "name": "Koavf"
                    },
                    {
                        "userid": 205748,
                        "name": "Syndicate"
                    },
                    {
                        "userid": 207579,
                        "name": "DaveStacey"
                    },
                    {
                        "userid": 209166,
                        "name": "BadCRC"
                    },
                    {
                        "userid": 210455,
                        "name": "Josiah Rowe"
                    },
                    {
                        "userid": 211760,
                        "name": "Sdornan"
                    },
                    {
                        "userid": 213355,
                        "name": "SpNeo"
                    },
                    {
                        "userid": 214085,
                        "name": "Alvonruff"
                    },
                    {
                        "userid": 214232,
                        "name": "Mike Peel"
                    },
                    {
                        "userid": 214427,
                        "name": "Vegaswikian"
                    },
                    {
                        "userid": 214630,
                        "name": "Jb-adder"
                    },
                    {
                        "userid": 214973,
                        "name": "Ruthead"
                    },
                    {
                        "userid": 215652,
                        "name": "Klassykittychick"
                    },
                    {
                        "userid": 216352,
                        "name": "Ligulem"
                    },
                    {
                        "userid": 217132,
                        "name": "DaveH"
                    },
                    {
                        "userid": 217942,
                        "name": "JP Godfrey"
                    },
                    {
                        "userid": 218261,
                        "name": "Pyb"
                    },
                    {
                        "userid": 219031,
                        "name": "Brighterorange"
                    },
                    {
                        "userid": 219828,
                        "name": "Bhadani"
                    },
                    {
                        "userid": 220924,
                        "name": "MarnetteD"
                    },
                    {
                        "userid": 222815,
                        "name": "AySz88"
                    },
                    {
                        "userid": 224303,
                        "name": "Thinkpad"
                    },
                    {
                        "userid": 224548,
                        "name": "Fish and karate"
                    },
                    {
                        "userid": 226304,
                        "name": "JohnDBuell"
                    },
                    {
                        "userid": 228395,
                        "name": "VidTheKid"
                    },
                    {
                        "userid": 232051,
                        "name": "RobertG"
                    },
                    {
                        "userid": 232552,
                        "name": "Huskydog"
                    },
                    {
                        "userid": 236211,
                        "name": "JdforresterBot"
                    },
                    {
                        "userid": 236830,
                        "name": "TheMidnighters"
                    },
                    {
                        "userid": 237572,
                        "name": "GünniX"
                    },
                    {
                        "userid": 241337,
                        "name": "RexNL"
                    },
                    {
                        "userid": 244246,
                        "name": "RobyWayne"
                    },
                    {
                        "userid": 244713,
                        "name": "Kolbasz"
                    },
                    {
                        "userid": 244946,
                        "name": "Str1977"
                    },
                    {
                        "userid": 247411,
                        "name": "Thoughtclaw"
                    },
                    {
                        "userid": 247551,
                        "name": "NavarroJ"
                    },
                    {
                        "userid": 253594,
                        "name": "BradBeattie"
                    },
                    {
                        "userid": 259138,
                        "name": "CJLL Wright"
                    },
                    {
                        "userid": 259798,
                        "name": "Chobot"
                    },
                    {
                        "userid": 264030,
                        "name": "VolatileChemical"
                    },
                    {
                        "userid": 264914,
                        "name": "Cactus.man"
                    },
                    {
                        "userid": 266416,
                        "name": "Gwernol"
                    },
                    {
                        "userid": 267668,
                        "name": "Flcelloguy"
                    },
                    {
                        "userid": 268253,
                        "name": "Peter Grey"
                    },
                    {
                        "userid": 270413,
                        "name": "The Rambling Man"
                    },
                    {
                        "userid": 271058,
                        "name": "YurikBot"
                    },
                    {
                        "userid": 271168,
                        "name": "Wavelength"
                    },
                    {
                        "userid": 273160,
                        "name": "JayzinSmith"
                    },
                    {
                        "userid": 274704,
                        "name": "Gyre"
                    },
                    {
                        "userid": 275925,
                        "name": "Charles Gaudette"
                    },
                    {
                        "userid": 279219,
                        "name": "RussBot"
                    },
                    {
                        "userid": 281302,
                        "name": "Petesmiles"
                    },
                    {
                        "userid": 281545,
                        "name": "John Quincy Adding Machine"
                    },
                    {
                        "userid": 283160,
                        "name": "Anonymous editor"
                    },
                    {
                        "userid": 284140,
                        "name": "Garglebutt"
                    },
                    {
                        "userid": 292299,
                        "name": "Chensiyuan"
                    },
                    {
                        "userid": 292494,
                        "name": "Stephenb"
                    },
                    {
                        "userid": 293907,
                        "name": "Gaius Cornelius"
                    },
                    {
                        "userid": 294180,
                        "name": "CambridgeBayWeather"
                    },
                    {
                        "userid": 294423,
                        "name": "Waux J.V. Trident"
                    },
                    {
                        "userid": 297502,
                        "name": "Pelago"
                    },
                    {
                        "userid": 301395,
                        "name": "NawlinWiki"
                    },
                    {
                        "userid": 302207,
                        "name": "EWS23"
                    },
                    {
                        "userid": 303874,
                        "name": "Wiki alf"
                    },
                    {
                        "userid": 305208,
                        "name": "Leutha"
                    },
                    {
                        "userid": 305845,
                        "name": "Mike18xx"
                    },
                    {
                        "userid": 307365,
                        "name": "Ojcit"
                    },
                    {
                        "userid": 308824,
                        "name": "Nathan8225"
                    },
                    {
                        "userid": 313663,
                        "name": "Introgressive"
                    },
                    {
                        "userid": 314004,
                        "name": "RazorICE"
                    },
                    {
                        "userid": 314332,
                        "name": "J E Bailey"
                    },
                    {
                        "userid": 314721,
                        "name": "Howcheng"
                    },
                    {
                        "userid": 322763,
                        "name": "JFD"
                    },
                    {
                        "userid": 323196,
                        "name": "Jpbowen"
                    },
                    {
                        "userid": 326092,
                        "name": "Dahveed323"
                    },
                    {
                        "userid": 330638,
                        "name": "Dannyno"
                    },
                    {
                        "userid": 331742,
                        "name": "Semperf"
                    },
                    {
                        "userid": 331972,
                        "name": "Crasshopper"
                    },
                    {
                        "userid": 332841,
                        "name": "Tony1"
                    },
                    {
                        "userid": 334244,
                        "name": "Freshgavin"
                    },
                    {
                        "userid": 337167,
                        "name": "Kyle Barbour"
                    },
                    {
                        "userid": 338679,
                        "name": "Figaro"
                    },
                    {
                        "userid": 347558,
                        "name": "DavidBFox"
                    },
                    {
                        "userid": 352384,
                        "name": "Joshurtree"
                    },
                    {
                        "userid": 352579,
                        "name": "Wknight94"
                    },
                    {
                        "userid": 355698,
                        "name": "Pegship"
                    },
                    {
                        "userid": 355937,
                        "name": "Fallout boy"
                    },
                    {
                        "userid": 358536,
                        "name": "FF2010"
                    },
                    {
                        "userid": 365061,
                        "name": "2over0"
                    },
                    {
                        "userid": 369889,
                        "name": "TheMadBaron"
                    },
                    {
                        "userid": 370000,
                        "name": "Joshmaul"
                    },
                    {
                        "userid": 372114,
                        "name": "Thnidu"
                    },
                    {
                        "userid": 372290,
                        "name": "Nikkimaria"
                    },
                    {
                        "userid": 379085,
                        "name": "Bondegezou"
                    },
                    {
                        "userid": 379206,
                        "name": "JoBrodie"
                    },
                    {
                        "userid": 379878,
                        "name": "JQF"
                    },
                    {
                        "userid": 380571,
                        "name": "Canley"
                    },
                    {
                        "userid": 382365,
                        "name": "Ray Chason"
                    },
                    {
                        "userid": 393532,
                        "name": "Whobot"
                    },
                    {
                        "userid": 393711,
                        "name": "Tyrenius"
                    },
                    {
                        "userid": 394271,
                        "name": "MartinUK"
                    },
                    {
                        "userid": 395014,
                        "name": "Wbrameld"
                    },
                    {
                        "userid": 404042,
                        "name": "Kungfuadam"
                    },
                    {
                        "userid": 404654,
                        "name": "Bdve"
                    },
                    {
                        "userid": 408274,
                        "name": "SDS"
                    },
                    {
                        "userid": 410083,
                        "name": "Maxamegalon2000"
                    },
                    {
                        "userid": 411742,
                        "name": "Infinity0"
                    },
                    {
                        "userid": 411872,
                        "name": "GrinBot~enwiki"
                    },
                    {
                        "userid": 414819,
                        "name": "Kgf0"
                    },
                    {
                        "userid": 417539,
                        "name": "The Yeti"
                    },
                    {
                        "userid": 424181,
                        "name": "C mon"
                    },
                    {
                        "userid": 426646,
                        "name": "Pearce.duncan"
                    },
                    {
                        "userid": 426720,
                        "name": "Tuttleturtle"
                    },
                    {
                        "userid": 429547,
                        "name": "Sintonak.X"
                    },
                    {
                        "userid": 433328,
                        "name": "SmackBot"
                    },
                    {
                        "userid": 433988,
                        "name": "FocalPoint"
                    },
                    {
                        "userid": 434818,
                        "name": "Amcbride"
                    },
                    {
                        "userid": 438071,
                        "name": "Guildenstern42"
                    },
                    {
                        "userid": 438626,
                        "name": "Elonka"
                    },
                    {
                        "userid": 445354,
                        "name": "Moeron"
                    },
                    {
                        "userid": 445578,
                        "name": "David Kernow"
                    },
                    {
                        "userid": 445629,
                        "name": "Bobet"
                    },
                    {
                        "userid": 447153,
                        "name": "ÜberRegenbogen"
                    },
                    {
                        "userid": 452631,
                        "name": "KnowledgeOfSelf"
                    },
                    {
                        "userid": 453853,
                        "name": "D rholambda"
                    },
                    {
                        "userid": 455421,
                        "name": "McGeddon"
                    },
                    {
                        "userid": 456045,
                        "name": "Grazon"
                    },
                    {
                        "userid": 460581,
                        "name": "Pgk"
                    },
                    {
                        "userid": 463669,
                        "name": "Rrius"
                    },
                    {
                        "userid": 465682,
                        "name": "Blue520"
                    },
                    {
                        "userid": 469429,
                        "name": "IainP"
                    },
                    {
                        "userid": 472456,
                        "name": "Bwithh"
                    },
                    {
                        "userid": 473593,
                        "name": "Zyxw"
                    },
                    {
                        "userid": 476208,
                        "name": "Eaglizard"
                    },
                    {
                        "userid": 477460,
                        "name": "Eskimbot"
                    },
                    {
                        "userid": 479044,
                        "name": "Darklock"
                    },
                    {
                        "userid": 483219,
                        "name": "Frymaster"
                    },
                    {
                        "userid": 483481,
                        "name": "Arniep"
                    },
                    {
                        "userid": 487310,
                        "name": "Kintetsubuffalo"
                    },
                    {
                        "userid": 491924,
                        "name": "Man with two legs"
                    },
                    {
                        "userid": 492990,
                        "name": "Dbnull"
                    },
                    {
                        "userid": 493683,
                        "name": "Evanreyes"
                    },
                    {
                        "userid": 495722,
                        "name": "Slixi"
                    },
                    {
                        "userid": 502540,
                        "name": "Xaosflux"
                    },
                    {
                        "userid": 503014,
                        "name": "Müslimix"
                    },
                    {
                        "userid": 503067,
                        "name": "Yamaguchi先生"
                    },
                    {
                        "userid": 503748,
                        "name": "UnqstnableTruth"
                    },
                    {
                        "userid": 506580,
                        "name": "Finduilas 09"
                    },
                    {
                        "userid": 509743,
                        "name": "Oscarthecat"
                    },
                    {
                        "userid": 510132,
                        "name": "Skizzik"
                    },
                    {
                        "userid": 514304,
                        "name": "ERcheck"
                    },
                    {
                        "userid": 521359,
                        "name": "Wookipedian"
                    },
                    {
                        "userid": 521745,
                        "name": "Qtoktok"
                    },
                    {
                        "userid": 526174,
                        "name": "Happywaffle"
                    },
                    {
                        "userid": 534983,
                        "name": "Red star"
                    },
                    {
                        "userid": 541247,
                        "name": "MK8"
                    },
                    {
                        "userid": 543434,
                        "name": "Jprg1966"
                    },
                    {
                        "userid": 552157,
                        "name": "Kbajaj"
                    },
                    {
                        "userid": 569802,
                        "name": "Jellyman"
                    },
                    {
                        "userid": 575307,
                        "name": "DHN-bot~enwiki"
                    },
                    {
                        "userid": 576163,
                        "name": "Da Vynci"
                    },
                    {
                        "userid": 580942,
                        "name": "Darth Panda"
                    },
                    {
                        "userid": 587537,
                        "name": "Emurphy42"
                    },
                    {
                        "userid": 591728,
                        "name": "JohnWhitlock"
                    },
                    {
                        "userid": 593397,
                        "name": "Scwlong"
                    },
                    {
                        "userid": 599713,
                        "name": "Patleahy"
                    },
                    {
                        "userid": 601813,
                        "name": "MapleLeafFan04"
                    },
                    {
                        "userid": 607632,
                        "name": "Jahiegel"
                    },
                    {
                        "userid": 608550,
                        "name": "PragmaticallyWyrd"
                    },
                    {
                        "userid": 619619,
                        "name": "Ioscius"
                    },
                    {
                        "userid": 623903,
                        "name": "Racklever"
                    },
                    {
                        "userid": 624973,
                        "name": "Kindall"
                    },
                    {
                        "userid": 633622,
                        "name": "Echong"
                    },
                    {
                        "userid": 638137,
                        "name": "Britmax"
                    },
                    {
                        "userid": 641682,
                        "name": "Zvar"
                    },
                    {
                        "userid": 646928,
                        "name": "Bentley Banana"
                    },
                    {
                        "userid": 651084,
                        "name": "Divna Jaksic"
                    },
                    {
                        "userid": 653893,
                        "name": "KittyRainbow"
                    },
                    {
                        "userid": 656169,
                        "name": "Beckoner"
                    },
                    {
                        "userid": 670128,
                        "name": "ThatSoup"
                    },
                    {
                        "userid": 670947,
                        "name": "Cybercobra"
                    },
                    {
                        "userid": 676614,
                        "name": "TheLimbicOne"
                    },
                    {
                        "userid": 678615,
                        "name": "Duckbill"
                    },
                    {
                        "userid": 685195,
                        "name": "Chargh"
                    },
                    {
                        "userid": 690855,
                        "name": "Pwjb"
                    },
                    {
                        "userid": 699268,
                        "name": "Badgerpatrol"
                    },
                    {
                        "userid": 699764,
                        "name": "Msp0"
                    },
                    {
                        "userid": 700244,
                        "name": "BullRangifer"
                    },
                    {
                        "userid": 712629,
                        "name": "Bob Castle"
                    },
                    {
                        "userid": 716232,
                        "name": "Quatloo"
                    },
                    {
                        "userid": 722149,
                        "name": "Salamurai"
                    },
                    {
                        "userid": 729553,
                        "name": "Pilotguy"
                    },
                    {
                        "userid": 735031,
                        "name": "Ged UK"
                    },
                    {
                        "userid": 736651,
                        "name": "Ohconfucius"
                    },
                    {
                        "userid": 740638,
                        "name": "Michael David"
                    },
                    {
                        "userid": 743517,
                        "name": "Interwiki de~enwiki"
                    },
                    {
                        "userid": 747085,
                        "name": "HighwayCello"
                    },
                    {
                        "userid": 750223,
                        "name": "Rory096"
                    },
                    {
                        "userid": 753665,
                        "name": "Ser Amantio di Nicolao"
                    },
                    {
                        "userid": 754198,
                        "name": "Johncatsoulis"
                    },
                    {
                        "userid": 754622,
                        "name": "Rklawton"
                    },
                    {
                        "userid": 755454,
                        "name": "Sjbradshaw"
                    },
                    {
                        "userid": 760284,
                        "name": "JzG"
                    },
                    {
                        "userid": 760376,
                        "name": "Zahid Abdassabur"
                    },
                    {
                        "userid": 763568,
                        "name": "Molerat"
                    },
                    {
                        "userid": 764861,
                        "name": "John"
                    },
                    {
                        "userid": 782009,
                        "name": "SilkTork"
                    },
                    {
                        "userid": 782961,
                        "name": "Briantist"
                    },
                    {
                        "userid": 784330,
                        "name": "Gobonobo"
                    }
                ],
                "images": [
                    {
                        "ns": 6,
                        "title": "File:Blue pencil.svg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Commons-logo.svg"
                    },
                    {
                        "ns": 6,
                        "title": "File:DNA in Monty Python.jpg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Dirk Gently's Holistic Detective Agency.svg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Douglas Adams San Francisco.jpg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Douglas Adams Unterschrift (cropped).jpg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Douglas adams portrait cropped.jpg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Grave of Douglas Adams, Highgate.jpg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Towelday-Innsbruck.jpg"
                    },
                    {
                        "ns": 6,
                        "title": "File:Wikiquote-logo.svg"
                    }
                ],
                "langlinks": [
                    {
                        "lang": "af",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ar",
                        "title": "دوغلاس آدمز"
                    },
                    {
                        "lang": "arz",
                        "title": "دوجلاس ادامز"
                    },
                    {
                        "lang": "ast",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "az",
                        "title": "Duqlas Adams"
                    },
                    {
                        "lang": "azb",
                        "title": "داقلاس آدامز"
                    },
                    {
                        "lang": "bar",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "be",
                        "title": "Дуглас Адамс"
                    },
                    {
                        "lang": "be-x-old",
                        "title": "Дуглас Адамз"
                    },
                    {
                        "lang": "bg",
                        "title": "Дъглас Адамс"
                    },
                    {
                        "lang": "bn",
                        "title": "ডগলাস অ্যাডামস"
                    },
                    {
                        "lang": "bs",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ca",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "cs",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "cy",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "da",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "de",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "el",
                        "title": "Ντάγκλας Άνταμς"
                    },
                    {
                        "lang": "eo",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "es",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "et",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "eu",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "fa",
                        "title": "داگلاس آدامز"
                    },
                    {
                        "lang": "fi",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "fr",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ga",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "gl",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "he",
                        "title": "דאגלס אדמס"
                    },
                    {
                        "lang": "hr",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "hu",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "hy",
                        "title": "Դուգլաս Ադամս"
                    },
                    {
                        "lang": "id",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "io",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "is",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "it",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ja",
                        "title": "ダグラス・アダムズ"
                    },
                    {
                        "lang": "jv",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ka",
                        "title": "დაგლას ადამსი"
                    },
                    {
                        "lang": "ko",
                        "title": "더글러스 애덤스"
                    },
                    {
                        "lang": "la",
                        "title": "Duglassius Adams"
                    },
                    {
                        "lang": "lfn",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "lt",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "lv",
                        "title": "Duglass Adamss"
                    },
                    {
                        "lang": "mg",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "mk",
                        "title": "Даглас Адамс"
                    },
                    {
                        "lang": "ml",
                        "title": "ഡഗ്ലസ് ആഡംസ്"
                    },
                    {
                        "lang": "mr",
                        "title": "डग्लस अ‍ॅडम्स"
                    },
                    {
                        "lang": "mrj",
                        "title": "Адамс, Дуглас"
                    },
                    {
                        "lang": "nl",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "nn",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "no",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "oc",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "pa",
                        "title": "ਡਗਲਸ ਐਡਮਸ"
                    },
                    {
                        "lang": "pl",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "pt",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ro",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ru",
                        "title": "Адамс, Дуглас"
                    },
                    {
                        "lang": "sc",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "sco",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "sh",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "simple",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "sk",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "sl",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "sq",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "sr",
                        "title": "Даглас Адамс"
                    },
                    {
                        "lang": "sv",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "ta",
                        "title": "டக்ளஸ் ஆடம்ஸ்"
                    },
                    {
                        "lang": "tr",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "uk",
                        "title": "Дуглас Адамс"
                    },
                    {
                        "lang": "ur",
                        "title": "ڈگلس ایڈمس"
                    },
                    {
                        "lang": "vep",
                        "title": "Adams Duglas"
                    },
                    {
                        "lang": "vi",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "war",
                        "title": "Douglas Adams"
                    },
                    {
                        "lang": "zh",
                        "title": "道格拉斯·亚当斯"
                    }
                ],
                "pageviews": {
                    "2018-03-23": 1679,
                    "2018-03-24": 1448,
                    "2018-03-25": 1650,
                    "2018-03-26": 1615,
                    "2018-03-27": 1677,
                    "2018-03-28": 1564,
                    "2018-03-29": 1619,
                    "2018-03-30": 1501,
                    "2018-03-31": 1348,
                    "2018-04-01": 1440,
                    "2018-04-02": 1677,
                    "2018-04-03": 1652,
                    "2018-04-04": 1538,
                    "2018-04-05": 1863,
                    "2018-04-06": 1497,
                    "2018-04-07": 1972,
                    "2018-04-08": 1958,
                    "2018-04-09": 1818,
                    "2018-04-10": 1669,
                    "2018-04-11": 1531,
                    "2018-04-12": 1782,
                    "2018-04-13": 1506,
                    "2018-04-14": 1485,
                    "2018-04-15": 1658,
                    "2018-04-16": 1579,
                    "2018-04-17": 1751,
                    "2018-04-18": 1624,
                    "2018-04-19": 1443,
                    "2018-04-20": 1414,
                    "2018-04-21": 1246,
                    "2018-04-22": 1433,
                    "2018-04-23": 1571,
                    "2018-04-24": 1462,
                    "2018-04-25": 1494,
                    "2018-04-26": 1715,
                    "2018-04-27": 1807,
                    "2018-04-28": 1429,
                    "2018-04-29": 1416,
                    "2018-04-30": 1592,
                    "2018-05-01": 1542,
                    "2018-05-02": 1373,
                    "2018-05-03": 1464,
                    "2018-05-04": 1666,
                    "2018-05-05": 1320,
                    "2018-05-06": 1584,
                    "2018-05-07": 1540,
                    "2018-05-08": 1570,
                    "2018-05-09": 1433,
                    "2018-05-10": 1405,
                    "2018-05-11": 6900,
                    "2018-05-12": 1509,
                    "2018-05-13": 1361,
                    "2018-05-14": 1465,
                    "2018-05-15": 1598,
                    "2018-05-16": 1428,
                    "2018-05-17": 1613,
                    "2018-05-18": 1390,
                    "2018-05-19": 1189,
                    "2018-05-20": 1434,
                    "2018-05-21": 1523
                }
            }
        ],
        "backlinks": [
            {
                "pageid": 1132,
                "ns": 0,
                "title": "The Ashes"
            },
            {
                "pageid": 1868,
                "ns": 1,
                "title": "Talk:The Ashes"
            },
            {
                "pageid": 4961,
                "ns": 0,
                "title": "Bovril"
            },
            {
                "pageid": 7626,
                "ns": 0,
                "title": "Cetacea"
            },
            {
                "pageid": 8192,
                "ns": 0,
                "title": "Detective fiction"
            },
            {
                "pageid": 8209,
                "ns": 0,
                "title": "Doctor Who"
            },
            {
                "pageid": 13024,
                "ns": 0,
                "title": "Graham Chapman"
            },
            {
                "pageid": 13044,
                "ns": 0,
                "title": "Gin and tonic"
            },
            {
                "pageid": 13744,
                "ns": 0,
                "title": "List of humorists"
            },
            {
                "pageid": 14788,
                "ns": 0,
                "title": "Infocom"
            },
            {
                "pageid": 14789,
                "ns": 0,
                "title": "Interactive fiction"
            },
            {
                "pageid": 15858,
                "ns": 0,
                "title": "John Cleese"
            },
            {
                "pageid": 15907,
                "ns": 0,
                "title": "Jabberwocky"
            },
            {
                "pageid": 17967,
                "ns": 0,
                "title": "Liar paradox"
            },
            {
                "pageid": 18942,
                "ns": 0,
                "title": "Monty Python"
            },
            {
                "pageid": 19354,
                "ns": 0,
                "title": "May 25"
            },
            {
                "pageid": 19452,
                "ns": 0,
                "title": "May 11"
            },
            {
                "pageid": 19530,
                "ns": 0,
                "title": "March 11"
            },
            {
                "pageid": 20347,
                "ns": 0,
                "title": "Meaning of life"
            },
            {
                "pageid": 22530,
                "ns": 0,
                "title": "October 12"
            },
            {
                "pageid": 24145,
                "ns": 0,
                "title": "Pun"
            },
            {
                "pageid": 24936,
                "ns": 0,
                "title": "Pneumatic tube"
            },
            {
                "pageid": 25228,
                "ns": 0,
                "title": "Q.E.D."
            },
            {
                "pageid": 25867,
                "ns": 0,
                "title": "Richard Dawkins"
            },
            {
                "pageid": 26093,
                "ns": 1,
                "title": "Talk:Rape/Archive 5"
            },
            {
                "pageid": 26110,
                "ns": 0,
                "title": "List of fictional robots and androids"
            },
            {
                "pageid": 27485,
                "ns": 0,
                "title": "Slartibartfast"
            },
            {
                "pageid": 31347,
                "ns": 0,
                "title": "Trilogy"
            },
            {
                "pageid": 31353,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy"
            },
            {
                "pageid": 33139,
                "ns": 0,
                "title": "World Wide Web"
            },
            {
                "pageid": 33822,
                "ns": 0,
                "title": "Westwood Studios"
            },
            {
                "pageid": 34419,
                "ns": 0,
                "title": "Zork"
            },
            {
                "pageid": 34505,
                "ns": 0,
                "title": "Z-machine"
            },
            {
                "pageid": 34551,
                "ns": 0,
                "title": "2001"
            },
            {
                "pageid": 34575,
                "ns": 0,
                "title": "1952"
            },
            {
                "pageid": 34753,
                "ns": 0,
                "title": "1978"
            },
            {
                "pageid": 36995,
                "ns": 0,
                "title": "Cambridge"
            },
            {
                "pageid": 37589,
                "ns": 0,
                "title": "Dorset"
            },
            {
                "pageid": 38299,
                "ns": 0,
                "title": "Activision"
            },
            {
                "pageid": 40594,
                "ns": 0,
                "title": "Pseudonym"
            },
            {
                "pageid": 42515,
                "ns": 0,
                "title": "Infinite monkey theorem"
            },
            {
                "pageid": 45061,
                "ns": 0,
                "title": "From Hell"
            },
            {
                "pageid": 47761,
                "ns": 0,
                "title": "Hitchhiking"
            },
            {
                "pageid": 48713,
                "ns": 0,
                "title": "St John's College, Cambridge"
            },
            {
                "pageid": 49626,
                "ns": 0,
                "title": "Suspended (video game)"
            },
            {
                "pageid": 50223,
                "ns": 0,
                "title": "Dirk Gently's Holistic Detective Agency"
            },
            {
                "pageid": 50377,
                "ns": 1,
                "title": "Talk:Finnish language"
            },
            {
                "pageid": 51800,
                "ns": 0,
                "title": "Terry Jones"
            },
            {
                "pageid": 53606,
                "ns": 0,
                "title": "List of science-fiction authors"
            },
            {
                "pageid": 53878,
                "ns": 0,
                "title": "Betelgeuse"
            },
            {
                "pageid": 54633,
                "ns": 0,
                "title": "Thursday"
            },
            {
                "pageid": 56282,
                "ns": 0,
                "title": "The Salmon of Doubt"
            },
            {
                "pageid": 60133,
                "ns": 0,
                "title": "Foundation series"
            },
            {
                "pageid": 60364,
                "ns": 0,
                "title": "Mostly Harmless"
            },
            {
                "pageid": 63401,
                "ns": 0,
                "title": "Stephen Fry"
            },
            {
                "pageid": 65308,
                "ns": 0,
                "title": "Apocalyptic and post-apocalyptic fiction"
            },
            {
                "pageid": 65616,
                "ns": 0,
                "title": "List of British comedians"
            },
            {
                "pageid": 66042,
                "ns": 0,
                "title": "List of science fiction sitcoms"
            },
            {
                "pageid": 66047,
                "ns": 0,
                "title": "Comic science fiction"
            },
            {
                "pageid": 66939,
                "ns": 0,
                "title": "List of fantasy authors"
            },
            {
                "pageid": 69111,
                "ns": 0,
                "title": "So Long, and Thanks for All the Fish"
            },
            {
                "pageid": 70188,
                "ns": 0,
                "title": "Highgate Cemetery"
            },
            {
                "pageid": 75912,
                "ns": 0,
                "title": "Time Lord"
            },
            {
                "pageid": 77783,
                "ns": 0,
                "title": "Guildford"
            },
            {
                "pageid": 78548,
                "ns": 1,
                "title": "Talk:Douglas Adams"
            },
            {
                "pageid": 78936,
                "ns": 2,
                "title": "User:ChrispyH"
            },
            {
                "pageid": 78975,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy: The Original Radio Scripts"
            },
            {
                "pageid": 79904,
                "ns": 0,
                "title": "Ford Prefect (character)"
            },
            {
                "pageid": 79907,
                "ns": 0,
                "title": "The Meaning of Liff"
            },
            {
                "pageid": 82998,
                "ns": 0,
                "title": "Sniglet"
            },
            {
                "pageid": 84636,
                "ns": 0,
                "title": "OK Computer"
            },
            {
                "pageid": 87916,
                "ns": 0,
                "title": "Planets in science fiction"
            },
            {
                "pageid": 88468,
                "ns": 0,
                "title": "The Pirate Planet"
            },
            {
                "pageid": 88470,
                "ns": 0,
                "title": "Shada (Doctor Who)"
            },
            {
                "pageid": 88472,
                "ns": 0,
                "title": "City of Death"
            },
            {
                "pageid": 89074,
                "ns": 0,
                "title": "Kakapo"
            },
            {
                "pageid": 89388,
                "ns": 0,
                "title": "Trillian (software)"
            },
            {
                "pageid": 89603,
                "ns": 0,
                "title": "Joanna Lumley"
            },
            {
                "pageid": 91431,
                "ns": 3,
                "title": "User talk:Jbrave"
            },
            {
                "pageid": 92321,
                "ns": 0,
                "title": "Nonsense verse"
            },
            {
                "pageid": 92896,
                "ns": 0,
                "title": "Romana (Doctor Who)"
            },
            {
                "pageid": 93792,
                "ns": 0,
                "title": "Christopher Moore (author)"
            },
            {
                "pageid": 94097,
                "ns": 0,
                "title": "Highgate"
            },
            {
                "pageid": 94105,
                "ns": 0,
                "title": "Holloway, London"
            },
            {
                "pageid": 94222,
                "ns": 0,
                "title": "Penge"
            },
            {
                "pageid": 95855,
                "ns": 0,
                "title": "Islington"
            },
            {
                "pageid": 101888,
                "ns": 0,
                "title": "List of fictional computers"
            },
            {
                "pageid": 108137,
                "ns": 0,
                "title": "Montecito, California"
            },
            {
                "pageid": 140193,
                "ns": 0,
                "title": "Sheridan, Wyoming"
            },
            {
                "pageid": 140648,
                "ns": 0,
                "title": "The Long Dark Tea-Time of the Soul"
            },
            {
                "pageid": 141949,
                "ns": 0,
                "title": "Gretna Green"
            },
            {
                "pageid": 142580,
                "ns": 0,
                "title": "Misotheism"
            },
            {
                "pageid": 143372,
                "ns": 3,
                "title": "User talk:Lezek"
            },
            {
                "pageid": 143385,
                "ns": 1,
                "title": "Talk:Gin and tonic"
            },
            {
                "pageid": 143994,
                "ns": 0,
                "title": "Zaphod Beeblebrox"
            },
            {
                "pageid": 145128,
                "ns": 0,
                "title": "Algorithmic efficiency"
            },
            {
                "pageid": 148264,
                "ns": 0,
                "title": "The Digital Village"
            },
            {
                "pageid": 153103,
                "ns": 0,
                "title": "Jane Horrocks"
            },
            {
                "pageid": 158111,
                "ns": 0,
                "title": "Zebra crossing"
            },
            {
                "pageid": 159943,
                "ns": 0,
                "title": "Starship Titanic"
            },
            {
                "pageid": 159973,
                "ns": 0,
                "title": "Marvin the Paranoid Android"
            },
            {
                "pageid": 159979,
                "ns": 0,
                "title": "Arthur Dent"
            },
            {
                "pageid": 161366,
                "ns": 0,
                "title": "Tom Baker"
            },
            {
                "pageid": 165320,
                "ns": 0,
                "title": "Jodrell Bank Observatory"
            },
            {
                "pageid": 167583,
                "ns": 0,
                "title": "BBC Radio"
            },
            {
                "pageid": 168977,
                "ns": 0,
                "title": "Trillian (character)"
            },
            {
                "pageid": 169104,
                "ns": 1,
                "title": "Talk:Infocom"
            },
            {
                "pageid": 169201,
                "ns": 0,
                "title": "Neil Innes"
            },
            {
                "pageid": 169363,
                "ns": 0,
                "title": "Doctor Snuggles"
            },
            {
                "pageid": 169367,
                "ns": 0,
                "title": "John Lloyd (producer)"
            },
            {
                "pageid": 173560,
                "ns": 0,
                "title": "English novel"
            },
            {
                "pageid": 174653,
                "ns": 0,
                "title": "Parallel universes in fiction"
            },
            {
                "pageid": 175570,
                "ns": 0,
                "title": "Bloom County"
            },
            {
                "pageid": 175946,
                "ns": 0,
                "title": "David Gilmour"
            },
            {
                "pageid": 182263,
                "ns": 1,
                "title": "Talk:John Logie Baird"
            },
            {
                "pageid": 188472,
                "ns": 0,
                "title": "Level 42"
            },
            {
                "pageid": 190173,
                "ns": 0,
                "title": "List of years in literature"
            },
            {
                "pageid": 190185,
                "ns": 0,
                "title": "2001 in literature"
            },
            {
                "pageid": 190210,
                "ns": 0,
                "title": "1990 in literature"
            },
            {
                "pageid": 190213,
                "ns": 0,
                "title": "1987 in literature"
            },
            {
                "pageid": 190227,
                "ns": 0,
                "title": "1980 in literature"
            },
            {
                "pageid": 190228,
                "ns": 0,
                "title": "1979 in literature"
            },
            {
                "pageid": 190428,
                "ns": 0,
                "title": "1978 in literature"
            },
            {
                "pageid": 190921,
                "ns": 0,
                "title": "1952 in literature"
            },
            {
                "pageid": 191067,
                "ns": 0,
                "title": "1977 in literature"
            },
            {
                "pageid": 191173,
                "ns": 0,
                "title": "Life, the Universe and Everything"
            },
            {
                "pageid": 191178,
                "ns": 0,
                "title": "42 (number)"
            },
            {
                "pageid": 193278,
                "ns": 0,
                "title": "List of songs that retell a work of literature"
            },
            {
                "pageid": 195642,
                "ns": 0,
                "title": "List of works published posthumously"
            },
            {
                "pageid": 197730,
                "ns": 0,
                "title": "Alternate reality game"
            },
            {
                "pageid": 202349,
                "ns": 0,
                "title": "The Restaurant at the End of the Universe"
            },
            {
                "pageid": 202358,
                "ns": 0,
                "title": "Vogon"
            },
            {
                "pageid": 202380,
                "ns": 0,
                "title": "Dirk Gently"
            },
            {
                "pageid": 203621,
                "ns": 0,
                "title": "Cranleigh"
            },
            {
                "pageid": 204504,
                "ns": 0,
                "title": "Millennium"
            },
            {
                "pageid": 205512,
                "ns": 0,
                "title": "Monty Python's The Meaning of Life"
            },
            {
                "pageid": 206019,
                "ns": 0,
                "title": "Robert Sheckley"
            },
            {
                "pageid": 208439,
                "ns": 0,
                "title": "Not the Nine O'Clock News"
            },
            {
                "pageid": 210085,
                "ns": 0,
                "title": "Genre fiction"
            },
            {
                "pageid": 220066,
                "ns": 0,
                "title": "Encyclopedia Galactica"
            },
            {
                "pageid": 222453,
                "ns": 0,
                "title": "Geoffrey Perkins"
            },
            {
                "pageid": 222734,
                "ns": 1,
                "title": "Talk:Knights Who Say Ni"
            },
            {
                "pageid": 226741,
                "ns": 0,
                "title": "Earth in science fiction"
            },
            {
                "pageid": 226759,
                "ns": 1,
                "title": "Talk:Cardinal direction"
            },
            {
                "pageid": 230265,
                "ns": 0,
                "title": "Deaths in 2001"
            },
            {
                "pageid": 230698,
                "ns": 0,
                "title": "Helen Mirren"
            },
            {
                "pageid": 236707,
                "ns": 0,
                "title": "List of English novelists"
            },
            {
                "pageid": 236962,
                "ns": 0,
                "title": "Steve Meretzky"
            },
            {
                "pageid": 237992,
                "ns": 0,
                "title": "Griff Rhys Jones"
            },
            {
                "pageid": 240602,
                "ns": 0,
                "title": "Taunton"
            },
            {
                "pageid": 240698,
                "ns": 0,
                "title": "Return to Zork"
            },
            {
                "pageid": 246726,
                "ns": 2,
                "title": "User:Oliver Pereira/stuff"
            },
            {
                "pageid": 247619,
                "ns": 2,
                "title": "User:Fantasy/Films and Books"
            },
            {
                "pageid": 248723,
                "ns": 0,
                "title": "Online encyclopedia"
            },
            {
                "pageid": 255451,
                "ns": 0,
                "title": "List of science fiction novels"
            },
            {
                "pageid": 255938,
                "ns": 2,
                "title": "User:Arteitle"
            },
            {
                "pageid": 256799,
                "ns": 0,
                "title": "Aphorism"
            },
            {
                "pageid": 260914,
                "ns": 0,
                "title": "Orders of magnitude (numbers)"
            },
            {
                "pageid": 265408,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy (video game)"
            },
            {
                "pageid": 266356,
                "ns": 0,
                "title": "List of minor The Hitchhiker's Guide to the Galaxy characters"
            },
            {
                "pageid": 267247,
                "ns": 0,
                "title": "River dolphin"
            },
            {
                "pageid": 269742,
                "ns": 0,
                "title": "Eoin Colfer"
            },
            {
                "pageid": 270906,
                "ns": 0,
                "title": "Three-letter acronym"
            },
            {
                "pageid": 272687,
                "ns": 0,
                "title": "Stalbridge"
            },
            {
                "pageid": 275009,
                "ns": 0,
                "title": "Culture of the United Kingdom"
            },
            {
                "pageid": 275154,
                "ns": 0,
                "title": "Blackmore Vale"
            },
            {
                "pageid": 277135,
                "ns": 0,
                "title": "Person from Porlock"
            },
            {
                "pageid": 284515,
                "ns": 0,
                "title": "Timeline of hypertext technology"
            },
            {
                "pageid": 287801,
                "ns": 0,
                "title": "Hypermedia"
            },
            {
                "pageid": 292910,
                "ns": 0,
                "title": "Metafiction"
            },
            {
                "pageid": 294628,
                "ns": 0,
                "title": "2005 in film"
            },
            {
                "pageid": 295712,
                "ns": 0,
                "title": "Young Zaphod Plays It Safe"
            },
            {
                "pageid": 296550,
                "ns": 0,
                "title": "British literature"
            },
            {
                "pageid": 297098,
                "ns": 0,
                "title": "Creatures (video game series)"
            },
            {
                "pageid": 299530,
                "ns": 0,
                "title": "Brentwood School, Essex"
            },
            {
                "pageid": 299646,
                "ns": 0,
                "title": "Places in The Hitchhiker's Guide to the Galaxy"
            },
            {
                "pageid": 300228,
                "ns": 0,
                "title": "Charlie Bean"
            },
            {
                "pageid": 310029,
                "ns": 0,
                "title": "Layered Image File Format"
            },
            {
                "pageid": 310619,
                "ns": 0,
                "title": "Achewood"
            },
            {
                "pageid": 313242,
                "ns": 0,
                "title": "BSFA Award"
            },
            {
                "pageid": 313675,
                "ns": 0,
                "title": "SF Masterworks"
            },
            {
                "pageid": 323782,
                "ns": 0,
                "title": "Lalla Ward"
            },
            {
                "pageid": 324415,
                "ns": 0,
                "title": "The Ballad of Halo Jones"
            },
            {
                "pageid": 338183,
                "ns": 0,
                "title": "The Sirens of Titan"
            },
            {
                "pageid": 338984,
                "ns": 2,
                "title": "User:Midom"
            },
            {
                "pageid": 340620,
                "ns": 0,
                "title": "Didcot"
            },
            {
                "pageid": 343210,
                "ns": 0,
                "title": "Princess (car)"
            },
            {
                "pageid": 349853,
                "ns": 1,
                "title": "Talk:List of minor The Hitchhiker's Guide to the Galaxy characters"
            },
            {
                "pageid": 354536,
                "ns": 0,
                "title": "Son of Dracula (1974 film)"
            },
            {
                "pageid": 357020,
                "ns": 0,
                "title": "LucasArts adventure games"
            },
            {
                "pageid": 357820,
                "ns": 0,
                "title": "The Division Bell"
            },
            {
                "pageid": 361302,
                "ns": 0,
                "title": "Fenchurch Street railway station"
            },
            {
                "pageid": 364509,
                "ns": 0,
                "title": "The South Bank Show"
            },
            {
                "pageid": 366389,
                "ns": 0,
                "title": "The Mighty Boosh"
            },
            {
                "pageid": 367649,
                "ns": 1,
                "title": "Talk:Layered Image File Format"
            },
            {
                "pageid": 368834,
                "ns": 0,
                "title": "Pierre Menard, Author of the Quixote"
            },
            {
                "pageid": 371215,
                "ns": 0,
                "title": "Babel Fish (website)"
            },
            {
                "pageid": 376078,
                "ns": 0,
                "title": "List of environmental organizations"
            },
            {
                "pageid": 381007,
                "ns": 0,
                "title": "Professor Chronotis"
            },
            {
                "pageid": 381340,
                "ns": 0,
                "title": "St. Cedd's College, Cambridge"
            },
            {
                "pageid": 384096,
                "ns": 0,
                "title": "Where no man has gone before"
            },
            {
                "pageid": 386967,
                "ns": 0,
                "title": "Bureaucracy (video game)"
            },
            {
                "pageid": 387403,
                "ns": 0,
                "title": "Nonsense"
            },
            {
                "pageid": 395894,
                "ns": 0,
                "title": "Legend Entertainment"
            },
            {
                "pageid": 401906,
                "ns": 0,
                "title": "Don't Panic: The Official Hitchhiker's Guide to the Galaxy Companion"
            },
            {
                "pageid": 404289,
                "ns": 0,
                "title": "Menippean satire"
            },
            {
                "pageid": 405493,
                "ns": 0,
                "title": "Digital physics"
            },
            {
                "pageid": 407332,
                "ns": 0,
                "title": "Rickmansworth"
            },
            {
                "pageid": 408094,
                "ns": 0,
                "title": "Startopia"
            },
            {
                "pageid": 409282,
                "ns": 0,
                "title": "List of authors by name: A"
            },
            {
                "pageid": 414643,
                "ns": 2,
                "title": "User:Znode/About (old)"
            },
            {
                "pageid": 416095,
                "ns": 0,
                "title": "Psychic detective"
            },
            {
                "pageid": 418570,
                "ns": 0,
                "title": "Hugo Award for Best Dramatic Presentation"
            },
            {
                "pageid": 421613,
                "ns": 0,
                "title": "Douglas Noël Adams",
                "redirect": true
            },
            {
                "pageid": 423303,
                "ns": 1,
                "title": "Talk:John Titor/Archive-1"
            },
            {
                "pageid": 431695,
                "ns": 0,
                "title": "Paranoid Android"
            },
            {
                "pageid": 435076,
                "ns": 0,
                "title": "Mark Wing-Davey"
            },
            {
                "pageid": 442167,
                "ns": 0,
                "title": "Douglas Adams Biography",
                "redirect": true
            },
            {
                "pageid": 442720,
                "ns": 0,
                "title": "A Mind Forever Voyaging"
            },
            {
                "pageid": 443327,
                "ns": 3,
                "title": "User talk:Barbara Shack"
            },
            {
                "pageid": 455258,
                "ns": 0,
                "title": "List of Have I Got News for You episodes"
            },
            {
                "pageid": 455776,
                "ns": 2,
                "title": "User:Sunja"
            },
            {
                "pageid": 457118,
                "ns": 0,
                "title": "The Gathering (LAN party)"
            },
            {
                "pageid": 462395,
                "ns": 0,
                "title": "Week Ending"
            },
            {
                "pageid": 466470,
                "ns": 0,
                "title": "The Eyre Affair"
            },
            {
                "pageid": 471205,
                "ns": 0,
                "title": "Hipgnosis"
            },
            {
                "pageid": 475298,
                "ns": 0,
                "title": "Lost in a Good Book"
            },
            {
                "pageid": 478421,
                "ns": 2,
                "title": "User:Xyzzyva"
            },
            {
                "pageid": 478921,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy (novel)"
            },
            {
                "pageid": 484730,
                "ns": 0,
                "title": "Santa Cruz Operation"
            },
            {
                "pageid": 485270,
                "ns": 1,
                "title": "Talk:March 8"
            },
            {
                "pageid": 486569,
                "ns": 4,
                "title": "Wikipedia:Selected anniversaries/March"
            },
            {
                "pageid": 489675,
                "ns": 4,
                "title": "Wikipedia:Selected anniversaries/May"
            },
            {
                "pageid": 490358,
                "ns": 0,
                "title": "Grammy Award for Best Spoken Word Album"
            },
            {
                "pageid": 492356,
                "ns": 4,
                "title": "Wikipedia:Selected anniversaries/March 8"
            },
            {
                "pageid": 492642,
                "ns": 4,
                "title": "Wikipedia:Selected anniversaries/May 11"
            },
            {
                "pageid": 496053,
                "ns": 1,
                "title": "Talk:May 11"
            },
            {
                "pageid": 497016,
                "ns": 0,
                "title": "List of BBC Radio 4 programmes"
            },
            {
                "pageid": 507760,
                "ns": 4,
                "title": "Wikipedia:Selected anniversaries/All"
            },
            {
                "pageid": 508263,
                "ns": 0,
                "title": "Andrew Marshall (screenwriter)"
            },
            {
                "pageid": 510257,
                "ns": 0,
                "title": "Last Chance to See"
            },
            {
                "pageid": 510303,
                "ns": 1,
                "title": "Talk:DNA/Archive 6"
            },
            {
                "pageid": 511626,
                "ns": 0,
                "title": "Cultured meat"
            },
            {
                "pageid": 515856,
                "ns": 2,
                "title": "User:Wolf530"
            },
            {
                "pageid": 516802,
                "ns": 0,
                "title": "Dave Lebling"
            },
            {
                "pageid": 519769,
                "ns": 0,
                "title": "Bartleby, the Scrivener"
            },
            {
                "pageid": 529967,
                "ns": 0,
                "title": "List of fictional Cambridge colleges"
            },
            {
                "pageid": 530260,
                "ns": 2,
                "title": "User:Shyamal"
            },
            {
                "pageid": 538317,
                "ns": 2,
                "title": "User:Geeoharee"
            },
            {
                "pageid": 545919,
                "ns": 0,
                "title": "69,105"
            },
            {
                "pageid": 547679,
                "ns": 0,
                "title": "Wetwang"
            },
            {
                "pageid": 550719,
                "ns": 0,
                "title": "Brian Blessed"
            },
            {
                "pageid": 555606,
                "ns": 0,
                "title": "Douglas Noel Adams",
                "redirect": true
            },
            {
                "pageid": 561505,
                "ns": 1,
                "title": "Talk:Joris-Karl Huysmans"
            },
            {
                "pageid": 563943,
                "ns": 0,
                "title": "List of prostitutes and courtesans"
            },
            {
                "pageid": 564881,
                "ns": 2,
                "title": "User:Dunk"
            },
            {
                "pageid": 572317,
                "ns": 0,
                "title": "Blowin' in the Wind"
            },
            {
                "pageid": 573880,
                "ns": 0,
                "title": "Fine-tuned Universe"
            },
            {
                "pageid": 575803,
                "ns": 0,
                "title": "The Big Read"
            },
            {
                "pageid": 577249,
                "ns": 0,
                "title": "Grue (monster)"
            },
            {
                "pageid": 581509,
                "ns": 0,
                "title": "List of fictional diseases"
            },
            {
                "pageid": 581632,
                "ns": 0,
                "title": "Mountain gorilla"
            },
            {
                "pageid": 584144,
                "ns": 5,
                "title": "Wikipedia talk:Selected anniversaries/May 11"
            },
            {
                "pageid": 589105,
                "ns": 0,
                "title": "David Agnew"
            },
            {
                "pageid": 592368,
                "ns": 0,
                "title": "Towel Day"
            },
            {
                "pageid": 597408,
                "ns": 0,
                "title": "The Adventure Game"
            },
            {
                "pageid": 615224,
                "ns": 0,
                "title": "Leather Goddesses of Phobos"
            },
            {
                "pageid": 620267,
                "ns": 0,
                "title": "List of text-based computer games"
            },
            {
                "pageid": 623143,
                "ns": 0,
                "title": "18610 Arthurdent"
            },
            {
                "pageid": 623209,
                "ns": 0,
                "title": "List of minor planets named after people"
            },
            {
                "pageid": 626608,
                "ns": 0,
                "title": "Christopher Priest (novelist)"
            },
            {
                "pageid": 631711,
                "ns": 0,
                "title": "Comic novel"
            },
            {
                "pageid": 634686,
                "ns": 0,
                "title": "Greg Rucka"
            },
            {
                "pageid": 638514,
                "ns": 0,
                "title": "BBC Online"
            },
            {
                "pageid": 640911,
                "ns": 0,
                "title": "List of satirists and satires"
            },
            {
                "pageid": 646205,
                "ns": 0,
                "title": "Tyler Labine"
            },
            {
                "pageid": 647158,
                "ns": 0,
                "title": "List of fictional books"
            },
            {
                "pageid": 649005,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/How to Fly"
            },
            {
                "pageid": 654925,
                "ns": 0,
                "title": "Forbidden Planet (bookstore)"
            },
            {
                "pageid": 671958,
                "ns": 0,
                "title": "List of fictional Prime Ministers of the United Kingdom"
            },
            {
                "pageid": 675682,
                "ns": 2,
                "title": "User:HansWobbe"
            },
            {
                "pageid": 681311,
                "ns": 2,
                "title": "User:Edward/books"
            },
            {
                "pageid": 692345,
                "ns": 0,
                "title": "Fictional currency"
            },
            {
                "pageid": 697699,
                "ns": 0,
                "title": "Bop Ad",
                "redirect": true
            },
            {
                "pageid": 711878,
                "ns": 0,
                "title": "Radio Academy"
            },
            {
                "pageid": 712000,
                "ns": 2,
                "title": "User:Tormaroe"
            },
            {
                "pageid": 713873,
                "ns": 0,
                "title": "List of detective fiction authors"
            },
            {
                "pageid": 722670,
                "ns": 0,
                "title": "Tor Books"
            },
            {
                "pageid": 730146,
                "ns": 0,
                "title": "Simon Jones (actor)"
            },
            {
                "pageid": 731738,
                "ns": 1,
                "title": "Talk:Earth/Archive 1"
            },
            {
                "pageid": 732330,
                "ns": 0,
                "title": "Brian Moriarty"
            },
            {
                "pageid": 740817,
                "ns": 0,
                "title": "Mathematical coincidence"
            },
            {
                "pageid": 742979,
                "ns": 0,
                "title": "Adams, Douglas",
                "redirect": true
            },
            {
                "pageid": 753557,
                "ns": 0,
                "title": "Triumph of the Nerds"
            },
            {
                "pageid": 762801,
                "ns": 0,
                "title": "The Burkiss Way"
            },
            {
                "pageid": 763822,
                "ns": 0,
                "title": "Wishbringer"
            },
            {
                "pageid": 766489,
                "ns": 2,
                "title": "User:JoshG"
            },
            {
                "pageid": 797949,
                "ns": 2,
                "title": "User:Brandalone"
            },
            {
                "pageid": 799056,
                "ns": 0,
                "title": "Adams, Douglas Noel",
                "redirect": true
            },
            {
                "pageid": 804250,
                "ns": 0,
                "title": "Doctor Who spin-offs"
            },
            {
                "pageid": 814696,
                "ns": 2,
                "title": "User:Ben Lewis"
            },
            {
                "pageid": 822749,
                "ns": 0,
                "title": "So Long and Thanks for All the Shoes"
            },
            {
                "pageid": 823354,
                "ns": 0,
                "title": "Clun"
            },
            {
                "pageid": 825679,
                "ns": 2,
                "title": "User:Guybrush"
            },
            {
                "pageid": 839439,
                "ns": 1,
                "title": "Talk:Kakapo"
            },
            {
                "pageid": 843158,
                "ns": 0,
                "title": "San Diego Comic-Con"
            },
            {
                "pageid": 849869,
                "ns": 0,
                "title": "Rice pudding"
            },
            {
                "pageid": 852368,
                "ns": 0,
                "title": "Planetfall"
            },
            {
                "pageid": 855755,
                "ns": 4,
                "title": "Wikipedia:Reference desk archive/July 2004"
            },
            {
                "pageid": 856679,
                "ns": 0,
                "title": "Bernice Summerfield"
            },
            {
                "pageid": 859443,
                "ns": 0,
                "title": "Cornerstone (software)"
            },
            {
                "pageid": 861370,
                "ns": 0,
                "title": "The Lost Treasures of Infocom"
            },
            {
                "pageid": 864968,
                "ns": 2,
                "title": "User:Average Earthman"
            },
            {
                "pageid": 865381,
                "ns": 0,
                "title": "Deep Thought (chess computer)"
            },
            {
                "pageid": 867545,
                "ns": 0,
                "title": "The Five Doctors"
            },
            {
                "pageid": 869769,
                "ns": 0,
                "title": "Life on Other Planets"
            },
            {
                "pageid": 873352,
                "ns": 0,
                "title": "A113"
            },
            {
                "pageid": 875467,
                "ns": 0,
                "title": "Zork: Grand Inquisitor"
            },
            {
                "pageid": 878281,
                "ns": 1,
                "title": "Talk:Goulash"
            },
            {
                "pageid": 884156,
                "ns": 0,
                "title": "List of kakapo"
            },
            {
                "pageid": 897135,
                "ns": 1,
                "title": "Talk:Norse mythology/Archive 2"
            },
            {
                "pageid": 905614,
                "ns": 0,
                "title": "Tim Anderson (programmer)"
            },
            {
                "pageid": 908185,
                "ns": 0,
                "title": "List of races and species in The Hitchhiker's Guide to the Galaxy"
            },
            {
                "pageid": 911959,
                "ns": 0,
                "title": "Douglas adams",
                "redirect": true
            },
            {
                "pageid": 915262,
                "ns": 1,
                "title": "Talk:Googleplex"
            },
            {
                "pageid": 918635,
                "ns": 0,
                "title": "Anton Zeilinger"
            },
            {
                "pageid": 920676,
                "ns": 10,
                "title": "Template:The Hitchhiker's Guide to the Galaxy"
            },
            {
                "pageid": 920901,
                "ns": 0,
                "title": "Software versioning"
            },
            {
                "pageid": 930311,
                "ns": 0,
                "title": "Target Books"
            },
            {
                "pageid": 934494,
                "ns": 4,
                "title": "Wikipedia:Featured article candidates/Archived nominations/Index/August 2004"
            },
            {
                "pageid": 936829,
                "ns": 0,
                "title": "Zooey Deschanel"
            },
            {
                "pageid": 937210,
                "ns": 0,
                "title": "Fable (2004 video game)"
            },
            {
                "pageid": 944266,
                "ns": 0,
                "title": "Douglass adams",
                "redirect": true
            },
            {
                "pageid": 952380,
                "ns": 4,
                "title": "Wikipedia:Featured article candidates/Featured log/September 2004"
            },
            {
                "pageid": 955001,
                "ns": 0,
                "title": "Starcross (video game)"
            },
            {
                "pageid": 959741,
                "ns": 0,
                "title": "History of Doctor Who"
            },
            {
                "pageid": 982874,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy (film)"
            },
            {
                "pageid": 983931,
                "ns": 0,
                "title": "Enchanter (video game)"
            },
            {
                "pageid": 988730,
                "ns": 4,
                "title": "Wikipedia:People by year/Reports/All"
            },
            {
                "pageid": 990779,
                "ns": 2,
                "title": "User:Greyweather"
            },
            {
                "pageid": 996056,
                "ns": 0,
                "title": "The Utterly Utterly Merry Comic Relief Christmas Book"
            },
            {
                "pageid": 999864,
                "ns": 0,
                "title": "Trinity (video game)"
            },
            {
                "pageid": 1007332,
                "ns": 11,
                "title": "Template talk:IMDb/Archive 1"
            },
            {
                "pageid": 1012235,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/List of terms associated with the color..."
            },
            {
                "pageid": 1031386,
                "ns": 0,
                "title": "One of These Nights"
            },
            {
                "pageid": 1048304,
                "ns": 0,
                "title": "Zork Nemesis"
            },
            {
                "pageid": 1052343,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/Alt.fan.douglas-adams"
            },
            {
                "pageid": 1055432,
                "ns": 2,
                "title": "User:Fmobus"
            },
            {
                "pageid": 1060486,
                "ns": 0,
                "title": "ŽVPL"
            },
            {
                "pageid": 1063385,
                "ns": 0,
                "title": "Phrases from The Hitchhiker's Guide to the Galaxy"
            },
            {
                "pageid": 1075187,
                "ns": 0,
                "title": "Beyond Zork"
            },
            {
                "pageid": 1082023,
                "ns": 0,
                "title": "Mouseland"
            },
            {
                "pageid": 1088352,
                "ns": 0,
                "title": "Starstruck (comics)"
            },
            {
                "pageid": 1092923,
                "ns": 0,
                "title": "Google"
            },
            {
                "pageid": 1096189,
                "ns": 1,
                "title": "Talk:Doctor Who spin-offs"
            },
            {
                "pageid": 1104882,
                "ns": 0,
                "title": "List of University of Cambridge people"
            },
            {
                "pageid": 1105048,
                "ns": 2,
                "title": "User:Danarchy"
            },
            {
                "pageid": 1108523,
                "ns": 0,
                "title": "BayCon"
            },
            {
                "pageid": 1120443,
                "ns": 2,
                "title": "User:Jongarrettuk/Better writing guide (current draft)"
            },
            {
                "pageid": 1125164,
                "ns": 0,
                "title": "Bluebottle (character)"
            },
            {
                "pageid": 1133130,
                "ns": 1,
                "title": "Talk:The Hunting of the Snark"
            },
            {
                "pageid": 1137976,
                "ns": 0,
                "title": "Tredegar"
            },
            {
                "pageid": 1150156,
                "ns": 0,
                "title": "The Lurking Horror"
            },
            {
                "pageid": 1154339,
                "ns": 0,
                "title": "InvisiClues"
            },
            {
                "pageid": 1158276,
                "ns": 1,
                "title": "Talk:Kenny Kramer"
            },
            {
                "pageid": 1160425,
                "ns": 2,
                "title": "User:Akchizar"
            },
            {
                "pageid": 1167171,
                "ns": 0,
                "title": "Douglas Adams (disambiguation)"
            },
            {
                "pageid": 1167603,
                "ns": 5,
                "title": "Wikipedia talk:Manual of Style (dates and numbers)/Archive 9"
            },
            {
                "pageid": 1169469,
                "ns": 0,
                "title": "AC adapter"
            },
            {
                "pageid": 1172515,
                "ns": 0,
                "title": "Computronium"
            },
            {
                "pageid": 1186248,
                "ns": 3,
                "title": "User talk:ClockworkTroll/Name the Admin Candidate"
            },
            {
                "pageid": 1189187,
                "ns": 4,
                "title": "Wikipedia:Writing better articles"
            },
            {
                "pageid": 1196859,
                "ns": 1,
                "title": "Talk:Hysterical realism"
            },
            {
                "pageid": 1204144,
                "ns": 4,
                "title": "Wikipedia:Wikifun/Answers Round 3"
            },
            {
                "pageid": 1205556,
                "ns": 3,
                "title": "User talk:Supersexyspacemonkey"
            },
            {
                "pageid": 1207282,
                "ns": 4,
                "title": "Wikipedia:Today's featured article/August 2005"
            },
            {
                "pageid": 1207602,
                "ns": 4,
                "title": "Wikipedia:Today's featured article/August 15, 2005"
            },
            {
                "pageid": 1222851,
                "ns": 1,
                "title": "Talk:St. Albans School (Washington, D.C.)"
            },
            {
                "pageid": 1233835,
                "ns": 0,
                "title": "Geoffrey McGivern"
            },
            {
                "pageid": 1234601,
                "ns": 0,
                "title": "List of Monty Python's Flying Circus episodes"
            },
            {
                "pageid": 1271199,
                "ns": 0,
                "title": "Gweek"
            },
            {
                "pageid": 1292809,
                "ns": 0,
                "title": "Doctor in the House (franchise)"
            },
            {
                "pageid": 1330622,
                "ns": 4,
                "title": "Wikipedia:Featured article candidates/Infinite monkey theorem"
            },
            {
                "pageid": 1336807,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/Thrupp"
            },
            {
                "pageid": 1343174,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/Log/2004 December 28"
            },
            {
                "pageid": 1350858,
                "ns": 0,
                "title": "Charles Thomson (artist)"
            },
            {
                "pageid": 1364362,
                "ns": 0,
                "title": "Ghost Light (Doctor Who)"
            },
            {
                "pageid": 1422125,
                "ns": 1,
                "title": "Talk:Cesar Chavez"
            },
            {
                "pageid": 1428664,
                "ns": 2,
                "title": "User:DanP"
            },
            {
                "pageid": 1436404,
                "ns": 0,
                "title": "25924 Douglasadams"
            },
            {
                "pageid": 1442444,
                "ns": 2,
                "title": "User:Binabik80"
            },
            {
                "pageid": 1448618,
                "ns": 2,
                "title": "User:Dupont Circle"
            },
            {
                "pageid": 1454245,
                "ns": 0,
                "title": "Arthur: The Quest for Excalibur"
            },
            {
                "pageid": 1483318,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/Log/2005 February 9"
            },
            {
                "pageid": 1486610,
                "ns": 4,
                "title": "Wikipedia:Articles for deletion/Stupid Day"
            },
            {
                "pageid": 1486637,
                "ns": 0,
                "title": "Dirk Maggs"
            },
            {
                "pageid": 1523660,
                "ns": 2,
                "title": "User:Cross-eyedmary"
            },
            {
                "pageid": 1526800,
                "ns": 2,
                "title": "User:Stevensweet"
            },
            {
                "pageid": 1528843,
                "ns": 0,
                "title": "Quote... Unquote"
            },
            {
                "pageid": 1545056,
                "ns": 0,
                "title": "Mavis Enderby"
            },
            {
                "pageid": 1549047,
                "ns": 1,
                "title": "Talk:Places in The Hitchhiker's Guide to the Galaxy"
            },
            {
                "pageid": 1551800,
                "ns": 0,
                "title": "Mark Carwardine"
            },
            {
                "pageid": 1562000,
                "ns": 0,
                "title": "Dark Night of the Soul"
            },
            {
                "pageid": 1567800,
                "ns": 0,
                "title": "Publius Enigma"
            },
            {
                "pageid": 1571009,
                "ns": 0,
                "title": "Meanings of minor planet names: 25001–26000"
            },
            {
                "pageid": 1592412,
                "ns": 4,
                "title": "Wikipedia:Peer review/Surreal humour/archive1"
            },
            {
                "pageid": 1620397,
                "ns": 0,
                "title": "List of Doctor Who audio plays by Big Finish"
            },
            {
                "pageid": 1657443,
                "ns": 0,
                "title": "List of acronyms: D"
            },
            {
                "pageid": 1658024,
                "ns": 10,
                "title": "Template:Infocom games"
            },
            {
                "pageid": 1660306,
                "ns": 2,
                "title": "User:(et)t~enwiki"
            },
            {
                "pageid": 1660367,
                "ns": 1,
                "title": "Talk:Charlotte Corday"
            },
            {
                "pageid": 1666929,
                "ns": 0,
                "title": "Zork Zero"
            },
            {
                "pageid": 1667025,
                "ns": 0,
                "title": "Sorcerer (video game)"
            },
            {
                "pageid": 1667026,
                "ns": 0,
                "title": "Spellbreaker"
            },
            {
                "pageid": 1674691,
                "ns": 0,
                "title": "Deadline (video game)"
            },
            {
                "pageid": 1675049,
                "ns": 0,
                "title": "Zork: The Undiscovered Underground"
            },
            {
                "pageid": 1676028,
                "ns": 0,
                "title": "Infidel (video game)"
            },
            {
                "pageid": 1679146,
                "ns": 0,
                "title": "List of avian humanoids"
            },
            {
                "pageid": 1679361,
                "ns": 4,
                "title": "Wikipedia:Peer review/April 2005"
            },
            {
                "pageid": 1680819,
                "ns": 0,
                "title": "List of Google Easter eggs"
            },
            {
                "pageid": 1681535,
                "ns": 0,
                "title": "List of Doctor Who audio releases"
            },
            {
                "pageid": 1690791,
                "ns": 4,
                "title": "Wikipedia:Wikipedia Signpost/2005-04-11/DVD releases"
            },
            {
                "pageid": 1701285,
                "ns": 4,
                "title": "Wikipedia:WikiProject Doctor Who"
            },
            {
                "pageid": 1706444,
                "ns": 0,
                "title": "List of Doctor Who planets"
            },
            {
                "pageid": 1715687,
                "ns": 2,
                "title": "User:Joo"
            },
            {
                "pageid": 1723459,
                "ns": 4,
                "title": "Wikipedia:Wikipedia Signpost/2005-04-18/In the news"
            },
            {
                "pageid": 1728996,
                "ns": 0,
                "title": "The Witness (1983 video game)"
            },
            {
                "pageid": 1729657,
                "ns": 0,
                "title": "Cutthroats (video game)"
            },
            {
                "pageid": 1739819,
                "ns": 0,
                "title": "Seastalker"
            },
            {
                "pageid": 1740324,
                "ns": 0,
                "title": "Suspect (video game)"
            },
            {
                "pageid": 1740508,
                "ns": 0,
                "title": "The Key to Time"
            },
            {
                "pageid": 1740520,
                "ns": 0,
                "title": "Ballyhoo (video game)"
            },
            {
                "pageid": 1740765,
                "ns": 0,
                "title": "Hollywood Hijinx"
            },
            {
                "pageid": 1741077,
                "ns": 0,
                "title": "Graham Williams (television producer)"
            },
            {
                "pageid": 1744498,
                "ns": 0,
                "title": "Stationfall"
            },
            {
                "pageid": 1751154,
                "ns": 0,
                "title": "Moonmist"
            },
            {
                "pageid": 1754624,
                "ns": 0,
                "title": "Border Zone (video game)"
            },
            {
                "pageid": 1759092,
                "ns": 0,
                "title": "Nord and Bert Couldn't Make Head or Tail of It"
            },
            {
                "pageid": 1762140,
                "ns": 0,
                "title": "MTropolis"
            },
            {
                "pageid": 1764629,
                "ns": 0,
                "title": "Sherlock: The Riddle of the Crown Jewels"
            },
            {
                "pageid": 1769920,
                "ns": 0,
                "title": "Plundered Hearts"
            },
            {
                "pageid": 1775512,
                "ns": 0,
                "title": "James Clavell's Shōgun"
            },
            {
                "pageid": 1776754,
                "ns": 0,
                "title": "Sandra Dickinson"
            },
            {
                "pageid": 1777937,
                "ns": 0,
                "title": "Vancouver Public Library"
            },
            {
                "pageid": 1780174,
                "ns": 0,
                "title": "Journey (1989 video game)"
            },
            {
                "pageid": 1785518,
                "ns": 0,
                "title": "The Armageddon Factor"
            },
            {
                "pageid": 1788002,
                "ns": 1,
                "title": "Talk:The Library of Babel"
            },
            {
                "pageid": 1795840,
                "ns": 4,
                "title": "Wikipedia:Wikipedia Signpost/2005-05-02/In the news"
            },
            {
                "pageid": 1814888,
                "ns": 0,
                "title": "Matt Jones (writer)"
            },
            {
                "pageid": 1814949,
                "ns": 0,
                "title": "Christopher H. Bidmead"
            },
            {
                "pageid": 1816950,
                "ns": 0,
                "title": "The Space Museum"
            },
            {
                "pageid": 1830464,
                "ns": 0,
                "title": "Fooblitzky"
            },
            {
                "pageid": 1830629,
                "ns": 0,
                "title": "Leather Goddesses of Phobos 2: Gas Pump Girls Meet the Pulsating Inconvenience from Planet X!"
            },
            {
                "pageid": 1830993,
                "ns": 0,
                "title": "Goosnargh"
            },
            {
                "pageid": 1834162,
                "ns": 0,
                "title": "High Offley"
            },
            {
                "pageid": 1834408,
                "ns": 0,
                "title": "List of religious ideas in science fiction"
            },
            {
                "pageid": 1834899,
                "ns": 0,
                "title": "Zork I"
            },
            {
                "pageid": 1835612,
                "ns": 0,
                "title": "Circuit's Edge"
            },
            {
                "pageid": 1835691,
                "ns": 15,
                "title": "Category talk:Positional numeral systems"
            },
            {
                "pageid": 1843594,
                "ns": 1,
                "title": "Talk:Nonce word"
            },
            {
                "pageid": 1847772,
                "ns": 2,
                "title": "User:Zoso~enwiki"
            },
            {
                "pageid": 1854364,
                "ns": 100,
                "title": "Portal:Doctor Who/Did you know"
            },
            {
                "pageid": 1854829,
                "ns": 2,
                "title": "User:Linuxbeak/Desk"
            },
            {
                "pageid": 1854892,
                "ns": 101,
                "title": "Portal talk:Doctor Who"
            },
            {
                "pageid": 1859446,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy (radio series)"
            },
            {
                "pageid": 1867336,
                "ns": 2,
                "title": "User:Digital Watches"
            },
            {
                "pageid": 1869065,
                "ns": 2,
                "title": "User:JollyJeanGiant"
            },
            {
                "pageid": 1871192,
                "ns": 2,
                "title": "User:Arthur Holland"
            },
            {
                "pageid": 1879923,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy (TV series)"
            },
            {
                "pageid": 1886171,
                "ns": 0,
                "title": "Hitch-hiker's Guide to Europe"
            },
            {
                "pageid": 1886253,
                "ns": 2,
                "title": "User:Nick R/books"
            },
            {
                "pageid": 1892526,
                "ns": 0,
                "title": "Duck test"
            },
            {
                "pageid": 1895842,
                "ns": 0,
                "title": "Above the Title Productions"
            },
            {
                "pageid": 1897437,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy Primary and Secondary Phases"
            },
            {
                "pageid": 1897462,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Galaxy Tertiary to Hexagonal Phases"
            },
            {
                "pageid": 1902368,
                "ns": 0,
                "title": "Destiny of the Daleks"
            },
            {
                "pageid": 1910757,
                "ns": 101,
                "title": "Portal talk:Biography"
            },
            {
                "pageid": 1916697,
                "ns": 1,
                "title": "Talk:Śākaṭāyana"
            },
            {
                "pageid": 1922349,
                "ns": 0,
                "title": "To a Mouse"
            },
            {
                "pageid": 1926357,
                "ns": 6,
                "title": "File:Deeper Meaning of Liff front cover.jpg"
            },
            {
                "pageid": 1934413,
                "ns": 0,
                "title": "Upper Street"
            },
            {
                "pageid": 1935815,
                "ns": 6,
                "title": "File:Hitchhiker's Guide (book cover).jpg"
            },
            {
                "pageid": 1936415,
                "ns": 2,
                "title": "User:Bennity"
            },
            {
                "pageid": 1954022,
                "ns": 0,
                "title": "Wish You Were Here"
            },
            {
                "pageid": 1954684,
                "ns": 6,
                "title": "File:Ultimate Hitchhikers Guide front.jpg"
            },
            {
                "pageid": 1960616,
                "ns": 0,
                "title": "Douglas Adams at the BBC"
            },
            {
                "pageid": 1960792,
                "ns": 0,
                "title": "The Hitchhiker's Guide to the Future"
            },
            {
                "pageid": 1964193,
                "ns": 6,
                "title": "File:The Salmon of Doubt Macmillan front.jpg"
            },
            {
                "pageid": 1964229,
                "ns": 6,
                "title": "File:Last Chance to See Harmony front.jpg"
            },
            {
                "pageid": 1964254,
                "ns": 6,
                "title": "File:Last Chance to See Voyager front.jpg"
            },
            {
                "pageid": 1964312,
                "ns": 6,
                "title": "File:Mostly Harmless Harmony front.jpg"
            },
            {
                "pageid": 1965715,
                "ns": 6,
                "title": "File:H2G2 first comic front cover.jpg"
            },
            {
                "pageid": 1969973,
                "ns": 0,
                "title": "Out of the Trees"
            },
            {
                "pageid": 1970255,
                "ns": 0,
                "title": "Douglas Q. Adams"
            },
            {
                "pageid": 1971166,
                "ns": 0,
                "title": "Real Time (Doctor Who)"
            },
            {
                "pageid": 1979611,
                "ns": 0,
                "title": "Toby Longworth"
            },
            {
                "pageid": 1984591,
                "ns": 2,
                "title": "User:Captmondo"
            },
            {
                "pageid": 1988147,
                "ns": 0,
                "title": "Past Doctor Adventures"
            },
            {
                "pageid": 2013148,
                "ns": 0,
                "title": "January 1981"
            },
            {
                "pageid": 2017499,
                "ns": 2,
                "title": "User:ForteTwo"
            }
        ]
    }
}
"""

cache = {'info': {'status': 200}, 'query': query, 'response': response}



# -*- coding:utf-8 -*-

query = 'https://en.wikipedia.org/w/api.php?action=query&formatversion=2&iiprop=size|url|timestamp|extmetadata&prop=imageinfo&titles=File%3ADouglas%20adams%20portrait%20cropped.jpg'

response = r'''
{
    "continue": {
        "iistart": "2010-04-16T22:53:21Z",
        "continue": "||"
    },
    "query": {
        "pages": [
            {
                "ns": 6,
                "title": "File:Douglas adams portrait cropped.jpg",
                "missing": true,
                "known": true,
                "imagerepository": "shared",
                "imageinfo": [
                    {
                        "timestamp": "2010-04-16T22:54:28Z",
                        "size": 32915,
                        "width": 333,
                        "height": 386,
                        "url": "https://upload.wikimedia.org/wikipedia/commons/c/c0/Douglas_adams_portrait_cropped.jpg",
                        "descriptionurl": "https://commons.wikimedia.org/wiki/File:Douglas_adams_portrait_cropped.jpg",
                        "descriptionshorturl": "https://commons.wikimedia.org/w/index.php?curid=10031710",
                        "extmetadata": {
                            "DateTime": {
                                "value": "2010-04-16 22:54:28",
                                "source": "mediawiki-metadata",
                                "hidden": ""
                            },
                            "ObjectName": {
                                "value": "Douglas adams portrait cropped",
                                "source": "mediawiki-metadata",
                                "hidden": ""
                            },
                            "CommonsMetadataExtension": {
                                "value": 1.2,
                                "source": "extension",
                                "hidden": ""
                            },
                            "Categories": {
                                "value": "Douglas Adams|Portrait photographs of men|Self-published work|Uploaded with derivativeFX",
                                "source": "commons-categories",
                                "hidden": ""
                            },
                            "Assessments": {
                                "value": "",
                                "source": "commons-categories",
                                "hidden": ""
                            },
                            "ImageDescription": {
                                "value": "douglas adams inspired \"Hitch hikers guide to the galaxy\" H2G2 <a rel=\"nofollow\" class=\"external text\" href=\"http://www.hughes-photography.eu\">www.hughes-photography.eu</a>",
                                "source": "commons-desc-page"
                            },
                            "DateTimeOriginal": {
                                "value": "",
                                "source": "commons-desc-page"
                            },
                            "Credit": {
                                "value": "<ul>\n<li><a href=\"//commons.wikimedia.org/wiki/File:Douglas_adams_portrait.jpg\" title=\"File:Douglas adams portrait.jpg\">Douglas_adams_portrait.jpg</a></li>\n</ul>",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "Artist": {
                                "value": "<ul>\n<li>\n<a href=\"//commons.wikimedia.org/wiki/File:Douglas_adams_portrait.jpg\" title=\"File:Douglas adams portrait.jpg\">Douglas_adams_portrait.jpg</a>: <a rel=\"nofollow\" class=\"external text\" href=\"https://www.flickr.com/people/79664273@N00\">michael hughes</a> from berlin, germany</li>\n<li>derivative work: <a href=\"//commons.wikimedia.org/wiki/User:Beao\" title=\"User:Beao\">Bea</a><b><a href=\"//commons.wikimedia.org/wiki/User_talk:Beao\" title=\"User talk:Beao\">o</a></b>\n</li>\n</ul>",
                                "source": "commons-desc-page"
                            },
                            "LicenseShortName": {
                                "value": "CC BY-SA 2.0",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "UsageTerms": {
                                "value": "Creative Commons Attribution-Share Alike 2.0",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "AttributionRequired": {
                                "value": "true",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "LicenseUrl": {
                                "value": "https://creativecommons.org/licenses/by-sa/2.0",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "Copyrighted": {
                                "value": "True",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "Restrictions": {
                                "value": "",
                                "source": "commons-desc-page",
                                "hidden": ""
                            },
                            "License": {
                                "value": "cc-by-sa-2.0",
                                "source": "commons-templates",
                                "hidden": ""
                            }
                        }
                    }
                ]
            }
        ]
    }
}
'''

cache = {'query': query, 'response': response}



# -*- coding:utf-8 -*-

query = 'https://www.wikidata.org/w/api.php?action=wbgetentities&formatversion=2&languages=en&props=aliases|info|claims|descriptions|labels|sitelinks&redirects=yes&ids=Q10908976'

response = r"""{"entities":{"Q10908976":{"id":"Q10908976","missing":""}},"success":1}"""

cache = {'query': query, 'response': response}



# -*- coding:utf-8 -*-

query = 'https://en.wikipedia.org/w/api.php?action=query&formatversion=2&pllimit=500&prop=links&list=random&titles=List_of_programming_languages'

response = r"""
{
    "continue": {
        "plcontinue": "144146|0|Perl_Data_Language",
        "continue": "||"
    },
    "query": {
        "pages": [
            {
                "pageid": 144146,
                "ns": 0,
                "title": "List of programming languages",
                "links": [
                    {
                        "ns": 0,
                        "title": "A++"
                    }
                ]
            }
        ],
        "random": [
            {
                "id": 123,
                "ns": 0,
                "title": "RANDOM"
            }
        ]
    }
}
"""

cache = {'query': query,
         'response': response,
         'info': {'content-type': 'TEST', 'status': 200}}



# -*- coding:utf-8 -*-

"""
WPTools Wikidata module
~~~~~~~~~~~~~~~~~~~~~~~

Support for getting Wikidata.

https://www.wikidata.org/wiki/Wikidata:Data_access
"""

import collections
import re

from . import core
from . import utils


class WPToolsWikidata(core.WPTools):
    """
    WPToolsWikidata class
    """

    def __init__(self, *args, **kwargs):
        """
        Returns a WPToolsWikidata object

        Optional positional {params}:
        - [title]: <str> Mediawiki page title, file, category, etc.

        Optional keyword {params}:
        - [lang]: <str> Mediawiki language code (default='en')
        - [variant]: <str> Mediawiki language variant
        - [wikibase]: <str> Wikidata database ID (e.g. 'Q1')

        Optional keyword {flags}:
        - [silent]: <bool> do not echo page data if True
        - [skip]: <list> skip actions in this list
        - [verbose]: <bool> verbose output to stderr if True
        """
        super(WPToolsWikidata, self).__init__(*args, **kwargs)

        wikibase = kwargs.get('wikibase')
        if wikibase:
            self.params.update({'wikibase': wikibase})

        self.user_labels = None

    def _get_entity_prop(self, entity, prop):
        """
        returns Wikidata entity property value
        """
        variant = self.params.get('variant')
        lang = self.params.get('lang')

        if entity.get(prop):
            ent = entity[prop]
            try:
                return ent[variant or lang].get('value')
            except AttributeError:
                return ent.get('value')

    def _marshal_claims(self, query_claims):
        """
        set Wikidata entities from query claims
        """
        claims = reduce_claims(query_claims)
        # self.data['claimq'] = query_claims
        self.data['claims'] = claims

        entities = set()
        for eid in claims:
            if self.user_labels:
                if eid in self.user_labels or eid == 'P31':
                    entities.add(eid)  # P (property)
                else:
                    continue  # get only wanted entities
            else:
                entities.add(eid)  # P (property)

            for val in claims[eid]:
                if utils.is_text(val) and re.match(r'^Q\d+$', val):
                    entities.add(val)  # Q (item)

        self.data['entities'] = list(entities)

    def _pop_entities(self, limit=50):
        """
        returns up to limit entities and pops them off the list
        """
        pop = self.data['entities'][:limit]
        del self.data['entities'][:limit]
        return pop

    def _post_labels_updates(self):
        """
        updates possible after getting labels
        """
        self._update_wikidata()
        self._update_images()
        self._update_what()

    def _query(self, action, qobj):
        """
        returns wikidata query string
        """
        if action == 'labels':
            return qobj.labels(self._pop_entities())
        elif action == 'wikidata':
            return qobj.wikidata(self.params.get('title'),
                                 self.params.get('wikibase'))

    def _set_data(self, action):
        """
        capture Wikidata API response data
        """
        if action == 'labels':
            self._set_labels()

        if action == 'wikidata':
            self._set_wikidata()
            self.get_labels(show=False)

    def _set_labels(self):
        """
        set entity labels from get_labels()
        """
        data = self._load_response('labels')
        entities = data.get('entities') or []

        for ent in entities:
            label = self._get_entity_prop(entities[ent], 'labels')
            self.data['labels'][ent] = label

    def _set_title(self, item):
        """
        attempt to set title from wikidata
        """
        title = None
        lang = self.params['lang']
        label = self.data['label']

        if item.get('sitelinks'):
            for link in item['sitelinks']:
                if link == "%swiki" % lang:
                    title = item['sitelinks'][link]['title']
                    self.data['title'] = title.replace(' ', '_')

        if not self.data.get('title') and label:
            self.data['title'] = label.replace(' ', '_')

        if self.data.get('title') and not self.params.get('title'):
            self.params['title'] = self.data['title']

    def _set_wikidata(self):
        """
        set attributes derived from Wikidata (action=wbentities)
        """
        self.data['labels'] = {}
        self.data['wikidata'] = {}

        data = self._load_response('wikidata')
        entities = data.get('entities')
        item = entities.get(next(iter(entities)))

        self.data['wikidata_pageid'] = item.get('pageid')

        aliases = item.get('aliases')
        if aliases:
            aliases = [x['value'] for x in aliases[self.params['lang']]]
            self.data['aliases'] = aliases

        modified = item.get('modified')
        try:
            self.data['modified'].update({'wikidata': modified})
        except KeyError:
            self.data['modified'] = {'wikidata': modified}

        wikibase = item.get('id')
        if wikibase:
            self.data['wikibase'] = wikibase
            self.data['wikidata_url'] = utils.wikidata_url(wikibase)

        self.data['description'] = self._get_entity_prop(item, 'descriptions')
        self.data['label'] = self._get_entity_prop(item, 'labels')

        self._marshal_claims(item.get('claims'))
        self._set_title(item)

    def _update_images(self):
        """
        add images from Wikidata
        """
        wd_images = self.data['claims'].get('P18')  # image

        if wd_images:
            if not isinstance(wd_images, list):
                wd_images = [wd_images]

            if 'image' not in self.data:
                self.data['image'] = []

            for img_file in wd_images:
                self.data['image'].append({'file': img_file,
                                           'kind': 'wikidata-image'})

    def _update_what(self):
        """
        set what this thing is! "instance of (P31)"
        """
        if 'P31' not in self.data['claims']:  # missing Wikidata
            msg = ("Note: Wikidata item %s" % self.data['wikibase'],
                   "missing 'instance of' (P31)")
            utils.stderr(" ".join(msg))
            return

        instance_of = self.data['claims']['P31'][0]
        labels = self.data['labels']

        if instance_of in labels:
            self.data['what'] = labels[instance_of]

    def _update_wikidata(self):
        """
        set wikidata from claims and labels
        """
        claims = self.data['claims']

        for ent in claims:

            plabel = self.data['labels'].get(ent)  # P (property) label
            if plabel:
                plabel = "%s (%s)" % (plabel, ent)

            claim = []
            for item in claims[ent]:
                ilabel = item
                if utils.is_text(item) and re.match(r'^Q\d+$', item):
                    ilabel = self.data['labels'].get(item)  # Q (item) label
                    if ilabel:
                        ilabel = "%s (%s)" % (ilabel, item)

                if len(claims[ent]) == 1:
                    claim = ilabel
                else:
                    claim.append(ilabel)

            if plabel and ilabel:
                self.data['wikidata'][plabel] = claim

    def get_labels(self, show=False, proxy=None, timeout=0):
        """
        GET Wikidata:API (action=wbgetentities) for claims labels
        https://www.wikidata.org/w/api.php?action=help&modules=wbgetentities

        Required {data}: entities, claims
            data['claims']: {'P17': ['Q17'], 'P910': ['Q8854938'], ...}
            data['entities']: ['P17', 'Q17', 'P910', 'Q8854938', ...]

        Data captured:
            labels: {'P17': 'country', 'Q17': 'Japan', ...}
            wikidata: {'country (P17)': 'Japan (Q17)', ...}

        Use get_wikidata() to populate data['entities']
        """
        if 'entities' not in self.data:
            utils.stderr("No entities found.")
            return

        skip_flag = False
        if 'skip' in self.flags and 'labels' in self.flags['skip']:
            skip_flag = True

        while 'entities' in self.data and self.data['entities']:
            if skip_flag:
                break
            self._get('labels', show, proxy, timeout)

        if 'entities' in self.data:
            del self.data['entities']

        self._post_labels_updates()

        return self

    def get_wikidata(self, show=True, proxy=None, timeout=0):
        """
        GET Wikidata:API (action=wbgetentities) wikidata
        https://www.wikidata.org/w/api.php?action=help&modules=wbgetentities

        Required {params}: title OR wikibase
        - title: <str> Mediawiki page title, file, category, etc.
        - wikibase: <str> Wikidata item ID

        Optional {params}:
        - [lang]: <str> Mediawiki language code (default='en')
        - [variant]: <str> Mediawiki language variant

        Optional arguments:
        - [show]: <bool> echo page data if true
        - [proxy]: <str> use this HTTP proxy
        - [timeout]: <int> timeout in seconds (0=wait forever)

        Data captured:
        - aliases: <list> list of "also known as"
        - claims: <dict> intermediate Wikidata claims (compare to cache)
        - description: <str> Wikidata description
        - image: <dict> {wikidata-image} Wikidata Property:P18
        - label: <str> Wikidata label
        - labels: <str> list of resolved labels
        - modified (wikidata): <str> ISO8601 date and time
        - pageid: <int> Wikipedia database ID
        - requests: list of request actions made
        - title: <str> article title
        - what: <str> Wikidata Property:P31 "instance of"
        - wikibase: <str> Wikidata item ID
        - wikidata: <dict> resolved Wikidata claims
        - wikidata_url: <str> Wikidata URL
        """
        title = self.params.get('title')
        wikibase = self.params.get('wikibase')

        if not wikibase and not title:
            err = "get_wikidata needs wikibase or title"
            raise LookupError(err)

        self._get('wikidata', show, proxy, timeout)

        return self

    def wanted_labels(self, labels):
        """
        Specify only WANTED labels to minimize get_labels() requests

        Args:
        - labels: <list> of wanted labels.

        Example:
          page.wanted_labels(['P18', 'P31'])
        """
        if not isinstance(labels, list):
            raise ValueError("Input labels must be a list.")

        self.user_labels = labels


################################################################


def reduce_claims(query_claims):
    """
    returns claims as reduced dict {P: [Q's or values]}
        P = property
        Q = item
    """
    claims = collections.defaultdict(list)

    for claim, entities in query_claims.items():

        for ent in entities:

            try:
                snak = ent.get('mainsnak')
                snaktype = snak.get('snaktype')
                value = snak.get('datavalue').get('value')
            except AttributeError:
                claims[claim] = []

            try:
                if snaktype != 'value':
                    val = snaktype
                elif value.get('id'):
                    val = value.get('id')
                elif value.get('text'):
                    val = value.get('text')
                elif value.get('time'):
                    val = value.get('time')
                else:
                    val = value
            except AttributeError:
                val = value

            if not val or not [x for x in val if x]:
                raise ValueError("%s %s" % (claim, ent))

            claims[claim].append(val)

    return dict(claims)



# -*- coding:utf-8 -*-

query = 'https://en.wikipedia.org/w/api.php?action=query&bltitle=Douglas%20Adams&bllimit=500&formatversion=2&list=backlinks'

response = r"""
{
    "batchcomplete": true,
    "continue": {
        "blcontinue": "0|2062757",
        "continue": "-||"
    },
    "query": {
        "pages": [
            {
                "pageid": 8091,
                "ns": 0,
                "title": "Douglas Adams"
            }
        ],
        "random": [
            {
                "id": 30520069,
                "ns": 0,
                "title": "Island South Divisional Secretariat"
            }
        ],
        "backlinks": [
            {
                "pageid": 1132,
                "ns": 0,
                "title": "The Ashes"
            }
        ]
    }
}
"""

cache = {'query': query,
         'response': response,
         'info': {'content-type': 'TEST', 'status': 200}}
